@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -26,7 +26,7 @@
 # Library modules import
 #-------------------------------------------------------------------------------
 
-__all__ = ["autovnv","Base", "Pages"]
+__all__ = ["studymanager","Base", "Pages", "studymanager_gui", "trackcvg"]
 
 #-------------------------------------------------------------------------------
 # End
