@@ -611,7 +611,7 @@ class domain(base_domain):
                 # as no calculation is possible, then raise exception
                 for f in [self.package.srcdir, 'compile.log']:
                     self.copy_result(f)
-                raise RunCaseError('Compile or link error.')
+                self.error = 'compile or link'
 
     #---------------------------------------------------------------------------
 
@@ -620,6 +620,8 @@ class domain(base_domain):
         Copy data to the execution directory
         """
 
+        err_str = None
+
         # If we are using a previous preprocessing, simply link to it here
         if self.mesh_input:
             mesh_input = os.path.expanduser(self.mesh_input)
@@ -663,18 +665,16 @@ class domain(base_domain):
                 restart_input = os.path.join(self.case_dir, restart_input)
 
             if not os.path.exists(restart_input):
-                err_str = restart_input + ' does not exist.'
-                raise RunCaseError(err_str)
+                err_str = restart_input + ' does not exist.\n\n'
             elif not os.path.isdir(restart_input):
-                err_str = restart_input + ' is not a directory.'
-                raise RunCaseError(err_str)
+                err_str = restart_input + ' is not a directory.\n\n.'
             else:
                 self.symlink(restart_input,
                              os.path.join(self.exec_dir, 'restart'))
 
         # Partition input files
 
-        if self.partition_input != None:
+        if self.partition_input != None and not err_str:
 
             partition_input = os.path.expanduser(self.partition_input)
             if not os.path.isabs(partition_input):
@@ -689,6 +689,10 @@ class domain(base_domain):
                     self.symlink(partition_input,
                                  os.path.join(self.exec_dir, 'partition_input'))
 
+        if err_str:
+            sys.stderr.write(err_str)
+            self.error = 'data preparation'
+
     #---------------------------------------------------------------------------
 
     def preprocess(self):
@@ -1527,6 +1531,181 @@ class aster_domain(base_domain):
         if self.param:
             s.write('    Code_Aster   : ' + self.param + '\n')
 
+#-------------------------------------------------------------------------------
+
+# Cathare coupling
+
+class cathare_domain(domain):
+
+
+    #---------------------------------------------------------------------------
+
+    def __init__(self,
+                 package,                     # main package
+                 package_compute = None,      # package for compute environment
+                 name = None,                 # domain name
+                 n_procs_weight = None,       # recommended number of processes
+                 n_procs_min = None,          # min. number of processes
+                 n_procs_max = None,          # max. number of processes
+                 logging_args = None,         # command-line options for logging
+                 param = None,                # XML parameters file
+                 prefix = None,               # installation prefix
+                 cathare_case_file = None,    # Cathare case .dat file
+                 neptune_cfd_dom   = None,    # NEPTUNE_CFD domain
+                 adaptation = None):          # HOMARD adaptation script
+
+        domain.__init__(self,
+                        package,
+                        package_compute,
+                        name,
+                        n_procs_weight,
+                        n_procs_min,
+                        n_procs_max,
+                        logging_args,
+                        param,
+                        prefix,
+                        adaptation)
+
+        self.cathare_case_file = cathare_case_file
+        self.neptune_cfd_dom   = neptune_cfd_dom
+
+
+    #---------------------------------------------------------------------------
+
+    def read_parameter_file(self, param):
+
+        # Getting the .xml from NEPTUNE_CFD, since all definitions are made
+        # within its GUI and paramfile
+
+        nept_paramfile = os.path.join(self.data_dir,
+                                      '../../',
+                                      self.neptune_cfd_dom,
+                                      'DATA',
+                                      param)
+
+        ofile = open(nept_paramfile,'r').readlines()
+        nfile = open(os.path.join(self.data_dir, param),'w')
+        for line in ofile:
+            if 'api_type' not in line:
+                nfile.write(line)
+            else:
+                nfile.write('       <api_type>2</api_type>')
+
+        nfile.close()
+
+        if param != None:
+            root_str = self.package.code_name + '_GUI'
+            version_str = '2.0'
+            P = cs_xml_reader.Parser(os.path.join(self.data_dir, param),
+                                     root_str = root_str,
+                                     version_str = version_str)
+            params = P.getParams()
+            for k in list(params.keys()):
+                self.__dict__[k] = params[k]
+
+            self.param = param
+
+
+    #---------------------------------------------------------------------------
+
+    def prepare_cathare_data(self):
+        """
+        Copy the .xml from the neptune folder and compile the cathare
+        case file into a .so library
+        """
+
+        # Compiling the Cathare Case
+        orig = os.getcwd()
+
+        os.chdir(self.data_dir)
+
+        cathare_shell_cmd  = "chmod +x cathare_jdd_to_lib.sh \n"
+        cathare_shell_cmd += "./cathare_jdd_to_lib.sh " + self.cathare_case_file
+        os.system(cathare_shell_cmd)
+
+        os.chdir(orig)
+
+    #---------------------------------------------------------------------------
+
+    def prepare_data(self):
+        """
+        Copy data to the execution directory
+        """
+
+        # If we are using a previous preprocessing, simply link to it here
+        if self.mesh_input:
+            mesh_input = os.path.expanduser(self.mesh_input)
+            if not os.path.isabs(mesh_input):
+                mesh_input = os.path.join(self.case_dir, mesh_input)
+            link_path = os.path.join(self.exec_dir, 'mesh_input')
+            self.purge_result(link_path) # in case of previous run here
+            self.symlink(mesh_input, link_path)
+
+        # Compile the cathare case if needed
+        self.prepare_cathare_data()
+
+        # Copy data files
+
+        dir_files = os.listdir(self.data_dir)
+
+        if self.package.guiname in dir_files:
+            dir_files.remove(self.package.guiname)
+
+        for f in dir_files:
+            src = os.path.join(self.data_dir, f)
+            if os.path.isfile(src):
+                shutil.copy2(src, os.path.join(self.exec_dir, f))
+                if f == 'cs_user_scripts.py':  # Copy user script to results now
+                    shutil.copy2(src,  os.path.join(self.result_dir, f))
+
+        if not self.exec_solver:
+            return
+
+        # Call user script if necessary
+
+        if self.user_locals:
+            m = 'domain_prepare_data_add'
+            if m in self.user_locals.keys():
+                eval(m + '(self)', globals(), self.user_locals)
+                del self.user_locals[m]
+
+        # Restart files
+
+        if self.restart_input != None:
+
+            restart_input =  os.path.expanduser(self.restart_input)
+            if not os.path.isabs(restart_input):
+                restart_input = os.path.join(self.case_dir, restart_input)
+
+            if not os.path.exists(restart_input):
+                err_str = restart_input + ' does not exist.'
+                raise RunCaseError(err_str)
+            elif not os.path.isdir(restart_input):
+                err_str = restart_input + ' is not a directory.'
+                raise RunCaseError(err_str)
+            else:
+                self.symlink(restart_input,
+                             os.path.join(self.exec_dir, 'restart'))
+
+        # Partition input files
+
+        if self.partition_input != None:
+
+            partition_input = os.path.expanduser(self.partition_input)
+            if not os.path.isabs(partition_input):
+                partition_input = os.path.join(self.case_dir, partition_input)
+
+            if os.path.exists(partition_input):
+
+                if not os.path.isdir(partition_input):
+                    err_str = partition_input + ' is not a directory.'
+                    raise RunCaseError(err_str)
+                else:
+                    self.symlink(partition_input,
+                                 os.path.join(self.exec_dir, 'partition_input'))
+
+    #---------------------------------------------------------------------------
+
 #-------------------------------------------------------------------------------
 # End
 #-------------------------------------------------------------------------------
