@@ -106,6 +106,10 @@ def process_cmd_line(argv, pkg):
                       metavar="<ast_case>",
                       help="create a new Code_Aster case.")
 
+    parser.add_option("--cathare", dest="cat_case_name", type="string",
+                      metavar="<cat_case>",
+                      help="create a new Cathare2 case.")
+
     parser.set_defaults(use_ref=True)
     parser.set_defaults(study_name=os.path.basename(os.getcwd()))
     parser.set_defaults(case_names=[])
@@ -115,6 +119,7 @@ def process_cmd_line(argv, pkg):
     parser.set_defaults(n_sat=1)
     parser.set_defaults(syr_case_names=[])
     parser.set_defaults(ast_case_name=None)
+    parser.set_defaults(cat_case_name=None)
 
     (options, args) = parser.parse_args(argv)
 
@@ -132,6 +137,7 @@ def process_cmd_line(argv, pkg):
                  options.case_names,
                  options.syr_case_names,
                  options.ast_case_name,
+                 options.cat_case_name,
                  options.copy,
                  options.import_only,
                  options.use_ref,
@@ -211,7 +217,7 @@ def syrthes_path_line(pkg):
 class Study:
 
     def __init__(self, package, name, cases, syr_case_names, ast_case_name,
-                 copy, import_only, use_ref, verbose):
+                 cat_case_name, copy, import_only, use_ref, verbose):
         """
         Initialize the structure for a study.
         """
@@ -239,6 +245,8 @@ class Study:
 
         self.ast_case_name = ast_case_name
 
+        self.cat_case_name = cat_case_name
+
         if self.import_only:
             self.use_ref = False
             self.copy = None
@@ -285,8 +293,17 @@ class Study:
                 sys.stderr.write("Cannot locate Code_Aster installation.")
                 sys.exit(1)
 
+        if self.cat_case_name is not None:
+            config = configparser.ConfigParser()
+            config.read(self.package.get_configfiles())
+            if config.has_option('install', 'cathare'):
+                self.create_cathare_case(repbase, config.get('install', 'cathare'))
+            else:
+                sys.stderr.write("Cannot locate Cathare installation.")
+                sys.exit(1)
+
         # Creating coupling structure
-        if len(self.cases) + len(self.syr_case_names) > 1 or self.ast_case_name:
+        if len(self.cases) + len(self.syr_case_names) > 1 or self.ast_case_name or self.cat_case_name:
             self.create_coupling(repbase)
 
 
@@ -337,6 +354,38 @@ class Study:
             sys.exit(1)
 
 
+    def create_cathare_case(self, repbase, cathare_path):
+        """
+        Create and initialize Cathare case directory for coupling.
+        """
+
+        os.chdir(repbase)
+        self.create_case(self.cat_case_name)
+
+        # Copying the Cathare coupling necessary files for the cases
+        datadir = os.path.join(self.package.get_dir("datadir"),
+                               self.package.name)
+
+        if os.path.isdir(os.path.join(datadir, 'cathare_coupling')):
+
+            cathare_cpl_dir = os.path.join(datadir, 'cathare_coupling')
+
+            # Script which converts the Cathare JDD file to a .so library
+            fin  = open(os.path.join(cathare_cpl_dir, 'user_scripts', 'cathare_jdd_to_lib.sh'))
+            fout = open(os.path.join(repbase, self.cat_case_name, 'DATA', 'cathare_jdd_to_lib.sh'), 'wt')
+            for line in fin:
+                fout.write(line.replace('#path_to_v25_3=',
+                                        'path_to_v25_3='+cathare_path))
+            fin.close()
+            fout.close()
+
+
+        else:
+            sys.stderr.write("Cannot find the directory: " + \
+                             os.path.join(datadir, 'cathare_coupling') + "\n")
+            sys.exit(1)
+
+
     def create_coupling(self, repbase):
         """
         Create structure to enable code coupling.
@@ -443,6 +492,30 @@ domains = [
 """
             dict_str += template
 
+        if self.cat_case_name is not None:
+
+            c = os.path.normpath(self.cat_case_name)
+            base_c = os.path.basename(c)
+
+            template = \
+"""
+    ,
+    {'solver': 'CATHARE',
+     'domain': 'DOMAIN',
+     'script': 'runcase',
+     'paramfile': 'setup.xml',
+     'cathare_case_file': 'jdd_case.dat',
+     'neptune_cfd_domain': 'NEPTUNE',
+     'n_procs_weight': None,
+     'n_procs_min': 1,
+     'n_procs_max': 1}
+"""
+
+            template = re.sub(e_pkg, solver_name, template)
+            template = re.sub(e_dom, base_c, template)
+
+            dict_str += template
+
         # Now finish building dictionnary string
 
         dict_str += \
@@ -470,9 +543,17 @@ domains = [
 
         fd.write(dict_str)
 
+        if self.cat_case_name is not None:
+            config = configparser.ConfigParser()
+            config.read(self.package.get_configfiles())
+            cathare_libpath=os.path.join(config.get('install', 'cathare'), 'lib')
+        else:
+            cathare_libpath=None
+
         self.build_batch_file(distrep = repbase,
                               casename = 'coupling',
-                              coupling = coupling_base)
+                              coupling = coupling_base,
+                              cathare_path = cathare_libpath)
 
 
     def create_case(self, casename):
@@ -515,7 +596,6 @@ domains = [
             ref           = os.path.join(data, 'REFERENCE')
             os.mkdir(ref)
             for f in ['dp_C3P', 'dp_C3PSJ', 'dp_C4P', 'dp_ELE',
-                      'dp_FCP.xml',
                       'dp_FUE', 'dp_transfo', 'meteo']:
                 abs_f = os.path.join(thch_distpath, f)
                 if os.path.isfile(abs_f):
@@ -605,7 +685,10 @@ domains = [
             # Source files
 
             ref_src = os.path.join(self.copy, src)
-            src_files = os.listdir(ref_src)
+            if os.path.exists(ref_src):
+                src_files = os.listdir(ref_src)
+            else:
+                src_files = []
 
             c_files = fnmatch.filter(src_files, '*.c')
             cxx_files = fnmatch.filter(src_files, '*.cxx')
@@ -636,7 +719,7 @@ domains = [
                               casename = casename)
 
 
-    def build_batch_file(self, distrep, casename, coupling=None):
+    def build_batch_file(self, distrep, casename, coupling=None, cathare_path=None):
         """
         Retrieve batch file for the current system
         Update batch file for the study
@@ -666,6 +749,18 @@ domains = [
         if coupling:
             runcase.set_coupling(coupling)
 
+        # If a cathare LIBPATH is given, it is added to LD_LIBRARY_PATH.
+        # This modification is needed for the dlopen of the cathare .so file
+        if cathare_path:
+            new_line="export LD_PATH_LIBRARY="+cathare_path+":$LD_LIBRARY_PATH"
+            il=0
+            for line in runcase.lines:
+                il+=1
+                if 'export PATH' in line:
+                    runcase.lines.insert(il, new_line)
+                    runcase.run_cmd_line_id += 1
+                    break
+
         runcase.save()
 
 
