@@ -45,6 +45,8 @@ rank_id = -1
 # List of supported debuggers
 
 debuggers = {"gdb": "GNU gdb debugger",
+             "cgdb": "Console front-end to gdb",
+             "gdbgui": "gdbgui gdb web browser interface",
              "ddd": "Data Display Debugger",
              "emacs": "Emacs with gdb debugger",
              "emacs23": "Emacs 23 or older with gdb debugger",
@@ -107,6 +109,7 @@ Debugger options:
   --asan-bp              Adds a breakpoint for gcc's Address-Sanitizer
   --back-end=GDB         Path to debugger back-end (for graphical front-ends)
   --breakpoints=LIST     Comma-separated list of breakpoints to insert
+  --terminal=TERM        Select terminal type to use for console debugger
 
   Other, standard options specific to each debugger may also be
   used, as long as they do not conflict with options in this script.
@@ -155,6 +158,8 @@ def process_cmd_line(argv, pkg):
                  "mpiexec": -1,
                  "program": -1}
 
+    debugger_options = ("asan-bp", "back-end", "breakpoints", "terminal")
+
     files = []
 
     p = ['.'] + os.getenv('PATH').split(':')
@@ -170,7 +175,8 @@ def process_cmd_line(argv, pkg):
         else:
             b = a[2:]
         if b in positions:
-            positions[b] = idx
+            if positions[b] < 0 or positions[b] > idx:
+                positions[b] = idx
             if a == '--debugger=list':
                 for k in debuggers.keys():
                     print(k + ': ' + debuggers[k])
@@ -286,6 +292,41 @@ def process_cmd_line(argv, pkg):
                     p_min = positions[s]
             cmds['debugger'] = [debugger] + argv[0:p_min]
 
+    # For for debugger options which might have appeared first
+    # check only now to avoid minor risk of similarly-named options
+    # for other tools
+
+    idx_s = 0
+    idx_e = -1
+    for k in ('debugger', 'mpiexec', 'valgrind', 'program'):
+        if positions[k] > -1:
+            idx_e = positions[k]
+            break;
+
+    idx_mpi = positions['mpiexec'] # in case placed first in the future
+    if idx_mpi > -1 and idx_mpi < idx_e:
+        idx_e = idx_mpi
+
+    idx = 0
+    for idx in range(idx_s, idx_e):
+        a = argv[idx]
+        ie = a[2:].find("=")
+        if ie > -1:
+            b = a[2:ie+2]
+        else:
+            b = a[2:]
+
+        if b in debugger_options:
+            idx_s = idx
+            break
+
+    try:
+        if cmds['debugger']:
+            for idx in range(idx_s, idx_e):
+                cmds['debugger'].insert(idx-idx_s + 1, argv[idx])
+    except Exception:
+        pass
+
     return cmds
 
 #-------------------------------------------------------------------------------
@@ -357,14 +398,13 @@ def run_minimal_debug(path, args=None,
         cmd += [path]
         if args:
             cmd += args
-        print(cmd)
 
-    if debugger_ui == 'kdbg':
+    elif debugger_ui == 'kdbg':
         if args:
             cmd += ['-a'] + args
         cmd += [path]
 
-    if debugger_ui == 'gede':
+    elif debugger_ui == 'gede':
         cmd += ['--args', path]
         if args:
             cmd += args
@@ -383,6 +423,18 @@ def run_minimal_debug(path, args=None,
 
     return subprocess.call(cmd)
 
+#-------------------------------------------------------------------------------
+# Find available port (for gdbgui)
+#-------------------------------------------------------------------------------
+
+def find_free_port():
+    import socket
+    tcp = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    tcp.bind(('', 0))
+    addr, port = tcp.getsockname()
+    tcp.close()
+    return port
+
 #-------------------------------------------------------------------------------
 # Run gdb-based or compatible debugger.
 #-------------------------------------------------------------------------------
@@ -403,7 +455,7 @@ def run_gdb_debug(path, args=None, gdb_cmds=None,
             target = True
             cmds.append(gdb_cmds[0])
 
-    # Check if we already have a commands file
+    # Check if we already have a command file
 
     cmds.append('b main')
 
@@ -438,6 +490,12 @@ def run_gdb_debug(path, args=None, gdb_cmds=None,
 
     debugger_command_file = None
 
+    term = os.getenv('TERM')
+    if not term:
+        term = 'xterm'
+    elif term[:5] == 'xterm':
+        term = 'xterm'
+
     if debugger_opts:
         file_next = False
         for o in debugger_opts:
@@ -452,7 +510,9 @@ def run_gdb_debug(path, args=None, gdb_cmds=None,
                 for bp in o[o.find('=')+1:].split(','):
                     cmds.append('b ' + bp)
             elif o == '--asan-bp': # gcc Adress sanitizer breakpoints
-                cmds.append('b __asan_report_error')
+                cmds.append('b __asan::ReportGenericError')
+            elif o.find('--terminal=') == 0: # Specify terminal
+                term = o[o.find('=')+1:]
             else:
                 cmd.append(o)
 
@@ -476,18 +536,24 @@ def run_gdb_debug(path, args=None, gdb_cmds=None,
 
     # Start building command to run
 
-    if debugger_ui == 'terminal':
-        if rank_id < 0:
+    if debugger_ui in ['terminal', 'cgdb']:
+        if rank_id < 0 and not target:
             cmd = [str(debugger)] + cmd
         else:
             cmd_string = str(debugger)
             for c in cmd:
                 cmd_string += ' ' + enquote_arg(str(c))
-            term = os.getenv('TERM')
-            if not term:
-                term = xterm
             cmd = [term, '-e', cmd_string]
 
+    elif debugger_ui == 'gdbgui':
+        cmd.insert(0, debugger)
+        if gdb != 'gdb':
+            cmd.insert(1, gdb)
+            cmd.insert(1, '--gdb')
+        p = find_free_port()
+        cmd.insert(1, str(p))
+        cmd.insert(1, '-p')
+
     elif debugger_ui == 'ddd':
         cmd.insert(0, debugger)
         if gdb != 'gdb':
@@ -595,7 +661,8 @@ def run_vgdb_debug(path,
 # Run program under Valgrind.
 #-------------------------------------------------------------------------------
 
-def run_valgrind(path, args=None, valgrind='valgrind', valgrind_opts=None):
+def run_valgrind(path, args=None, valgrind='valgrind', valgrind_opts=None,
+                 debugger_opts=None):
     """
     Run program under Valgrind.
     """
@@ -623,14 +690,17 @@ def run_valgrind(path, args=None, valgrind='valgrind', valgrind_opts=None):
 
     # Start building command to run
 
-    if rank_id < 0:
-        return subprocess.call(cmd)
-
-    else:
-        if debugger_attach:
+    if debugger_attach:
+        if rank_id < 0:
+            return subprocess.call(cmd)
+        else:
             term = os.getenv('TERM')
             if not term:
                 term = xterm
+            if debugger_opts:
+                for o in debugger_opts:
+                    if o.find('--terminal=') == 0: # Specify terminal
+                        term = o[o.find('=')+1:]
 
             cmd_line = term + ' -e "' + valgrind
             for c in cmd[1:]:
@@ -639,16 +709,16 @@ def run_valgrind(path, args=None, valgrind='valgrind', valgrind_opts=None):
 
             return subprocess.call(cmd_line, shell=True)
 
+    else:
+        if rank_id > 0:
+            vg_f = open('valgrind.out.r' + str(rank_id), 'w')
+            returncode = subprocess.call(cmd,
+                                         stdout=vg_f,
+                                         stderr=subprocess.STDOUT)
+            vg_f.close()
+            return returncode
         else:
-            if rank_id > 0:
-                vg_f = open('valgrind.out.r' + str(rank_id), 'w')
-                returncode = subprocess.call(cmd,
-                                             stdout=vg_f,
-                                             stderr=subprocess.STDOUT)
-                vg_f.close()
-                return returncode
-            else:
-                return subprocess.call(cmd)
+            return subprocess.call(cmd)
 
 #-------------------------------------------------------------------------------
 # Run debugger
@@ -734,10 +804,14 @@ def run_debug(cmds):
             return p.returncode
 
     elif 'valgrind' in cmds.keys():
+        debugger_opts = None
+        if 'debugger' in cmds.keys():
+            debugger_opts = cmds['debugger'][1:]
         return run_valgrind(path = cmds['program'][0],
                             args = cmds['program'][1:],
                             valgrind = cmds['valgrind'][0],
-                            valgrind_opts = cmds['valgrind'][1:])
+                            valgrind_opts = cmds['valgrind'][1:],
+                            debugger_opts = debugger_opts)
 
     # We should not reach this area.
 
