@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -32,33 +32,34 @@
 # cflags_default_dbg     # Added to $CFLAGS for debugging    (default: "-g")
 # cflags_default_opt     # Added to $CFLAGS for optimization (default: "-O")
 # cflags_default_hot     # Optimization for specific files   (default: "-O")
-# cflags_default_prf     # Added to $CFLAGS for profiling    (default: "")
+# cflags_default_prf     # Added to $CFLAGS for profiling    (default: "-g")
 # cflags_default_omp     # Added to $CFLAGS for OpenMP       (default: "")
 
 # cxxflags_default       # Base CXXFLAGS                       (default: "")
 # cxxflags_default_dbg   # Added to $CXXFLAGS for debugging    (default: "-g")
 # cxxflags_default_opt   # Added to $CXXFLAGS for optimization (default: "-O")
 # cxxflags_default_hot   # Optimization for specific files     (default: "-O")
-# cxxflags_default_prf   # Added to $CXXFLAGS for profiling    (default: "")
+# cxxflags_default_prf   # Added to $CXXFLAGS for profiling    (default: "-g")
 # cxxflags_default_omp   # Added to $CXXFLAGS for OpenMP       (default: "")
+# cxxflags_default_std   # C++ standard variant                (default: "")
 
 # fcflags_default        # Base FCFLAGS                       (default: "")
 # fcflags_default_dbg    # Added to $FCFLAGS for debugging    (default: "-g")
 # fcflags_default_opt    # Added to $FCFLAGS for optimization (default: "-O")
 # fcflags_default_hot    # Optimization for specific files    (default: "-O")
-# fcflags_default_prf    # Added to $FCFLAGS for profiling    (default: "")
+# fcflags_default_prf    # Added to $FCFLAGS for profiling    (default: "-g")
 # fcflags_default_omp    # Added to $FCFLAGS for OpenMP       (default: "")
 #
 # ldflags_default        # Base LDFLAGS                       (default: "")
 # ldflags_default_dbg    # Added to $LDFLAGS for debugging    (default: "-g")
 # ldflags_default_opt    # Added to $LDFLAGS for optimization (default: "-O")
-# ldflags_default_prf    # Added to $LDFLAGS for profiling    (default: "")
+# ldflags_default_prf    # Added to $LDFLAGS for profiling    (default: "-g")
 # ldflags_rpath          # Added to $LDFLAGS for shared libs  (default: "")
 
 # libs_default           # Base LIBS                          (default: "")
-# libs_default_dbg       # Added to $LDFLAGS for debugging    (default: "")
-# libs_default_opt       # Added to $LDFLAGS for optimization (default: "")
-# libs_default_prf       # Added to $LDFLAGS for profiling    (default: "")
+# libs_default_dbg       # Added to $LIBS for debugging       (default: "")
+# libs_default_opt       # Added to $LIBS for optimization    (default: "")
+# libs_default_prf       # Added to $LIBS for profiling       (default: "")
 
 # Two other environment variable strings are defined, containing possibly
 # more detailed compiler information:
@@ -128,6 +129,8 @@ esac
 cs_ac_cc_version=unknown
 cs_cc_compiler_known=no
 
+cflags_default_prf="-g"
+
 # Are we using gcc ?
 #-------------------
 
@@ -183,7 +186,6 @@ if test "x$cs_gcc" = "xgcc"; then
   cflags_default_dbg="-g"
   cflags_default_opt="-O2"
   cflags_default_hot="-O3"
-  cflags_default_prf="-pg"
   cflags_default_omp="-fopenmp"
 
   # Modify default flags on certain systems
@@ -270,7 +272,6 @@ elif test "x$cs_gcc" = "xicc"; then
   cflags_default_dbg="-g -O0 -traceback -w2 -Wp64 -ftrapuv"
   cflags_default_opt="-O2"
   cflags_default_hot="-O3"
-  cflags_default_prf="-p"
   cflags_default_omp="-qopenmp"
   case "$cs_cc_vers_major" in
     1[0123456])
@@ -298,7 +299,6 @@ elif test "x$cs_gcc" = "xclang"; then
   cflags_default_dbg="-g -O0"
   cflags_default_opt="-O2"
   cflags_default_hot="-O3"
-  cflags_default_prf="-p"
   cflags_default_omp="-fopenmp=libomp"
 
 # Otherwise, are we using pathcc ?
@@ -322,7 +322,6 @@ elif test "x$cs_gcc" = "xpathcc"; then
     cflags_default_dbg="-g"
     cflags_default_opt="-O2"
     cflags_default_hot="-Ofast"
-    cflags_default_prf=""
     cflags_default_omp="-openmp"
 
   fi
@@ -349,7 +348,6 @@ if test "x$cs_cc_compiler_known" != "xyes" ; then
     cflags_default_dbg="-g -Mbounds"
     cflags_default_opt="-O2"
     cflags_default_hot="-fast"
-    cflags_default_prf="-Mprof=func,lines"
     cflags_default_omp="-mp"
 
   fi
@@ -377,14 +375,12 @@ if test "x$cs_cc_compiler_known" != "xyes" ; then
     cflags_default_opt="-O3"
     cflags_default_hot="-O3"
     cflags_default_dbg="-g -qfullpath"
-    cflags_default_prf="-pg -qfullpath"
     cflags_default_omp="-qsmp=omp -qthreaded"
 
     # Default  linker flags
     ldflags_default=""
     ldflags_default_opt="-O3"
     ldflags_default_dbg="-g -qfullpath"
-    ldflags_default_prf="-pg -qfullpath"
     ldflags_rpath="-R"
 
     # Adjust options for IBM Blue Gene cross-compiler
@@ -425,14 +421,12 @@ if test "x$cs_cc_compiler_known" != "xyes" ; then
     cflags_default_opt="-O2"
     cflags_default_hot="-O3"
     cflags_default_dbg="-g"
-    cflags_default_prf="-h profile_generate" # resulting code must be run under CrayPat
     cflags_default_omp="-h omp"              # default: use "-h noomp" to disable
 
     # Default  linker flags
     ldflags_default=""
     ldflags_default_opt="-O2"
     ldflags_default_dbg="-g"
-    ldflags_default_prf="-h profile_generate"
 
   fi
 fi
@@ -452,7 +446,6 @@ if test "x$cs_cc_compiler_known" != "xyes" ; then
       cflags_default=""
       cflags_default_opt="-O"
       cflags_default_dbg="-g"
-      cflags_default_prf=""
       cflags_default_omp=""
       ;;
 
@@ -479,6 +472,8 @@ fi
 cs_ac_cxx_version=unknown
 cs_cxx_compiler_known=no
 
+cxxflags_default_prf="-g"
+
 # Are we using g++ ?
 #-------------------
 
@@ -530,12 +525,12 @@ if test "x$cs_gxx" = "xg++"; then
   test -n "$cs_cxx_vers_patch" || cs_cxx_vers_patch=0
 
   # Default compiler flags
-  cxxflags_default="-ansi -funsigned-char -W -Wall -Wshadow -Wpointer-arith -Wcast-qual -Wcast-align -Wwrite-strings -Wunused -Wno-long-long -Wfloat-equal"
+  cxxflags_default="-W -Wall -Wshadow -Wpointer-arith -Wcast-qual -Wcast-align -Wwrite-strings -Wunused -Wfloat-equal"
   cxxflags_default_dbg="-g"
   cxxflags_default_opt="-O2"
   cxxflags_default_hot="-O3"
-  cxxflags_default_prf="-pg"
   cxxflags_default_omp="-fopenmp"
+  cxxflags_default_std="-ansi -funsigned-char"
 
   # Modify default flags on certain systems
 
@@ -599,12 +594,12 @@ elif test "x$cs_gxx" = "xicc"; then
   test -n "$cs_cxx_vers_patch" || cs_cxx_vers_patch=0
 
   # Default compiler flags
-  cxxflags_default="-strict-ansi -funsigned-char -Wall -Wcheck -Wshadow -Wpointer-arith -Wmissing-prototypes -Wuninitialized -Wunused"
+  cxxflags_default="-Wall -Wcheck -Wshadow -Wpointer-arith -Wmissing-prototypes -Wuninitialized -Wunused"
   cxxflags_default_dbg="-g -O0 -traceback -w2 -Wp64 -ftrapuv"
   cxxflags_default_opt="-O2"
   cxxflags_default_hot="-O3"
-  cxxflags_default_prf="-p"
   cxxflags_default_omp="-qopenmp"
+  cxxflags_default_std="-strict-ansi -funsigned-char"
 
   case "$cs_cxx_vers_major" in
     1[0123456])
@@ -628,12 +623,12 @@ elif test "x$cs_gxx" = "xclang"; then
 
   # Default compiler flags
   # (temporarily disable "operands evaluated in unspecified order" remark -- 981)
-  cxxlags_default="-strict-ansi -funsigned-char -Wall -Wshadow -Wpointer-arith -Wmissing-prototypes -Wuninitialized -Wunused"
+  cxxlags_default="-Wall -Wshadow -Wpointer-arith -Wmissing-prototypes -Wuninitialized -Wunused"
   cxxflags_default_dbg="-g -O0"
   cxxflags_default_opt="-O2"
   cxxflags_default_hot="-O3"
-  cxxflags_default_prf="-p"
   cxxflags_default_omp="-fopenmp=libomp"
+  cxxflags_default_std="-strict-ansi -funsigned-char"
 
 # Otherwise, are we using pgcc ?
 #-------------------------------
@@ -651,11 +646,11 @@ else
     cs_cxx_compiler_known=yes
 
     # Default compiler flags
-    cxxflags_default="-Xa -noswitcherror"
+    cxxflags_default="-noswitcherror"
     cxxflags_default_dbg="-g -Mbounds"
     cxxflags_default_opt="-fast -fastsse"
-    cxxflags_default_prf="-Mprof=func,lines"
     cxxflags_default_omp="-mp"
+    cxxflags_default_std="-Xa"
 
   fi
 
@@ -681,8 +676,8 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
     cxxflags_default_opt="-O3"
     cxxflags_default_hot="-O3"
     cxxflags_default_dbg="-g"
-    cxxflags_default_prf="-pg"
     cxxflags_default_omp="-qsmp=omp -qthreaded"
+    cxxflags_default_std=""
 
     # Adjust options for IBM Blue Gene cross-compiler
 
@@ -719,8 +714,8 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
     cxxflags_default_opt="-O2"
     cxxflags_default_hot="-O3"
     cxxflags_default_dbg="-g"
-    cfxxlags_default_prf="-h profile_generate" # resulting code must be run under CrayPat
     cfxxlags_default_omp="-h omp"              # default: use "-h noomp" to disable
+    cxxflags_default_std=""
 
   fi
 
@@ -746,8 +741,8 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
     cxxflags_default_dbg="-g"
     cxxflags_default_opt="-O2"
     cxxflags_default_hot="-Ofast"
-    cxxflags_default_prf=""
     cxxflags_default_omp="-openmp"
+    cxxflags_default_std=""
 
   fi
 
@@ -768,8 +763,8 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
       cxxflags_default=""
       cxxflags_default_opt="-O"
       cxxflags_default_dbg="-g"
-      cxxflags_default_prf=""
       cxxflags_default_omp=""
+      cxxflags_default_std=""
       ;;
 
   esac
@@ -795,6 +790,8 @@ fi
 cs_ac_fc_version=unknown
 cs_fc_compiler_known=no
 
+fcflags_default_prf="-g"
+
 # Are we using gfortran ?
 #------------------------
 
@@ -847,7 +844,6 @@ if test "$?" = "0" ; then
   fcflags_default_dbg="-g -fcheck=bounds"
   fcflags_default_opt="-O"
   fcflags_default_hot="-O2"
-  fcflags_default_prf="-pg"
   fcflags_default_omp="-fopenmp"
 
   if test "xgfortran" = "x$cs_fc_vendor"; then
@@ -895,7 +891,6 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
     fcflags_default_dbg="-g -O0 -traceback -check all -check nopointer -fpe0 -ftrapuv"
     fcflags_default_opt="-O2"
     fcflags_default_hot="-O3"
-    fcflags_default_prf="-p"
     fcflags_default_omp="-qopenmp"
 
     case "$cs_cxx_vers_major" in
@@ -927,7 +922,6 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
     fcflags_default_dbg="-g -Mbounds"
     fcflags_default_opt="-O2"
     fcflags_default_hot="-fast"
-    fcflags_default_prf="-Mprof=func,lines"
     fcflags_default_omp="-mp"
 
   fi
@@ -953,7 +947,6 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
     fcflags_default="-q64 -qextname -qsuffix=cpp=f90"
     fcflags_default_dbg="-g"
     fcflags_default_opt="-O3"
-    fcflags_default_prf="-pg"
     fcflags_default_omp="-qsmp=omp -qthreaded"
 
     # Adjust options for IBM Blue Gene cross-compiler
@@ -992,7 +985,6 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
     fcflags_default="-eF -em -J."
     fcflags_default_dbg="-g"
     fcflags_default_opt="-O2"
-    fcflags_default_prf="-h profile_generate" # resulting code must be run under CrayPat
     fcflags_default_omp="-h omp"              # default: use "-h noomp" to disable
 
   fi
@@ -1018,7 +1010,6 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
     fcflags_default_dbg="-g -ffortran-bounds-check"
     fcflags_default_opt="-O"
     fcflags_default_hot="-fast"
-    fcflags_default_prf=""
     fcflags_default_omp="-openmp"
 
   fi
@@ -1037,7 +1028,6 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
       fcflags_default_opt="-O"
       fcflags_default_hot="-O"
       fcflags_default_dbg="-g"
-      fcflags_default_prf=""
       ;;
 
   esac
@@ -1063,6 +1053,8 @@ fi
 # Default linker flags
 #---------------------
 
+ldflags_default_prf="-g"
+
 if test "x$cs_linker_set" != "xyes" ; then
 
   case "$host_os" in
@@ -1071,7 +1063,6 @@ if test "x$cs_linker_set" != "xyes" ; then
       ldflags_default=""
       ldflags_default_opt="-O"
       ldflags_default_dbg="-g"
-      ldflags_default_prf="-pg"
       ldflags_rpath="-Wl,-rpath -Wl,"
       if test "x$cs_gfortran" = "xgfortran"; then
         libgfortran_path=`$FC --print-file-name=libgfortran.so`
@@ -1093,7 +1084,6 @@ if test "x$cs_linker_set" != "xyes" ; then
     *)
       ldflags_default_opt="-O"
       ldflags_default_dbg="-g"
-      ldflags_default_prf="-pg"
       ;;
 
   esac
