@@ -5,7 +5,7 @@
 #     This file is part of the Code_Saturne User Interface, element of the
 #     Code_Saturne CFD tool.
 #
-#     Copyright (C) 1998-2016 EDF S.A., France
+#     Copyright (C) 1998-2018 EDF S.A., France
 #
 #     contact: saturne-support@edf.fr
 #
@@ -37,7 +37,7 @@ Generic Dialog window to handle execution of a list of external scripts.
 # Standard modules
 #-------------------------------------------------------------------------------
 
-import os, string, logging
+import os, logging
 import signal, subprocess
 
 #-------------------------------------------------------------------------------
