@@ -31,9 +31,9 @@ This module defines the following classes:
 - NewCaseDialogView
 - MainView
 
-    @copyright: 1998-2017 EDF S.A., France
+    @copyright: 1998-2018 EDF S.A., France
     @author: U{EDF<mailto:saturne-support@edf.fr>}
-    @license: GNU GPL v2, see COPYING for details.
+    @license: GNU GPL v2 or later, see COPYING for details.
 """
 
 #-------------------------------------------------------------------------------
@@ -1536,6 +1536,7 @@ class MainViewSaturne(QMainWindow, Ui_MainForm, MainView):
         mdl = ScriptRunningModel(self.case)
         rt = mdl.getRunType(self.case['prepro'])
         self.case['prepro'] = True
+        self.case['oturns'] = False
         self.initCase()
         mdl.setRunType(rt)
         self.Browser.configureTree(self.case)
@@ -1555,6 +1556,7 @@ class MainViewSaturne(QMainWindow, Ui_MainForm, MainView):
         """
         mdl = ScriptRunningModel(self.case)
         self.case['prepro'] = False
+        self.case['oturns'] = False
         self.initCase()
         mdl.setRunType('standard')
         self.Browser.configureTree(self.case)
@@ -1568,6 +1570,24 @@ class MainViewSaturne(QMainWindow, Ui_MainForm, MainView):
             self.scrollArea.setWidget(p)
 
 
+    def slotOpenTurnsMode(self):
+        """
+        mode OpenTurns study slot
+        """
+        self.case['prepro'] = False
+        self.case['oturns'] = True
+        self.initCase()
+        self.Browser.configureTree(self.case)
+        if self.case['current_page'] == 'OpenTurns study':
+            p = displaySelectedPage(self.case['current_page'],
+                                    self,
+                                    self.case,
+                                    stbar=self.statusbar,
+                                    study=self.Id,
+                                    tree=self.Browser)
+            self.scrollArea.setWidget(p)
+
+
     def slotUndoRedoView(self):
         if self.case['undo']:
             self.actionUndo.setEnabled(True)
