@@ -50,7 +50,6 @@ from code_saturne.Pages.MobileMeshModel import MobileMeshModel
 from code_saturne.Pages.TurbulenceModel import TurbulenceModel
 from code_saturne.Pages.InitializationModel import InitializationModel
 from code_saturne.Pages.TimeStepModel import TimeStepModel
-from code_saturne.Pages.SteadyManagementModel import SteadyManagementModel
 from code_saturne.Pages.FluidCharacteristicsModel import FluidCharacteristicsModel
 from code_saturne.Pages.CoalCombustionModel import CoalCombustionModel
 from code_saturne.Pages.ThermalScalarModel import ThermalScalarModel
@@ -137,7 +136,7 @@ class XMLinit(Variables):
                 zone = LocalizationModel("VolumicZone", self.case).getCodeNumberOfZoneLabel('all_cells')
                 InitializationModel(self.case).getInitialTurbulenceChoice(zone)
 
-            # Time step
+            # Time settings
 
             TimeStepModel(self.case).getTimeStep()
             TimeStepModel(self.case).getIterationsNumber()
@@ -154,7 +153,6 @@ class XMLinit(Variables):
 
             # Calculation features
 
-            SteadyManagementModel(self.case).getSteadyFlowManagement()
             ThermalScalarModel(self.case).getThermalScalarModel()
             CoalCombustionModel(self.case).getCoalCombustionModel()
             GasCombustionModel(self.case).getGasCombustionModel()
@@ -224,7 +222,8 @@ class XMLinit(Variables):
         """
         known_versions = ["3.0", "3.1", "3.2", "3.3",
                           "4.0", "4.1", "4.2", "4.3",
-                          "5.0", "5.1"]
+                          "5.0", "5.1", "5.2", "5.3",
+                          "6.0"]
         j = -2
         for i in range(0, len(known_versions)):
             if vers.find(known_versions[i]) == 0:
@@ -245,12 +244,12 @@ class XMLinit(Variables):
         """
         Change XML in order to ensure backward compatibility.
         """
-        cur_vers = self.__clean_version(self.case['package'].version)
+        cur_vers = self.case['package'].version
 
         if self.case.root()["solver_version"]:
             his_r = self.case.root()["solver_version"]
             history = his_r.split(";")
-            last_vers = history[len(history) - 1]
+            last_vers = self.__clean_version(history[len(history) - 1])
             if last_vers == cur_vers:
                 self.__backwardCompatibilityCurrentVersion()
             else:
@@ -273,7 +272,8 @@ class XMLinit(Variables):
             vers = cur_vers
             self.case.root().xmlSetAttribute(solver_version = vers)
 
-            # apply all backwardCompatibility we don't know when it was created
+            # apply all backwardCompatibilities as we don't know
+            # when it was created
             self.__backwardCompatibilityOldVersion("-1")
             self.__backwardCompatibilityCurrentVersion()
 
@@ -305,6 +305,14 @@ class XMLinit(Variables):
             if from_vers[:3] < "5.0.0":
                 self.__backwardCompatibilityFrom_4_3()
 
+        if from_vers[:3] < "6.0.0":
+            if from_vers[:3] < "5.1.0":
+                self.__backwardCompatibilityFrom_5_0()
+            if from_vers[:3] < "5.2.0":
+                self.__backwardCompatibilityFrom_5_1()
+            if from_vers[:3] < "5.3.0":
+                self.__backwardCompatibilityFrom_5_2()
+
 
     def __backwardCompatibilityBefore_3_0(self):
         """
@@ -1334,7 +1342,6 @@ class XMLinit(Variables):
                 if node:
                     node.xmlRemoveNode()
 
-        XMLThermoPhysicalModelNode = self.case.xmlGetNode('thermophysical_models')
         node_joule = XMLThermoPhysicalModelNode.xmlGetNode('joule_effect', 'model')
         if node_joule:
             if node_joule['model'] != 'off':
@@ -1397,14 +1404,6 @@ class XMLinit(Variables):
                 if not node['name']:
                     node['name'] = node['label']
 
-
-    def __backwardCompatibilityCurrentVersion(self):
-        """
-        Change XML in order to ensure backward compatibility.
-        """
-
-        XMLThermoPhysicalModelNode = self.case.xmlInitNode('thermophysical_models')
-
         # fix name of thermal conductivity in radiative transfer node
         npr = XMLThermoPhysicalModelNode.xmlGetNode('radiative_transfer')
         if npr:
@@ -1412,6 +1411,14 @@ class XMLinit(Variables):
             if node:
                 node['name'] = "wall_thermal_conductivity"
 
+
+    def __backwardCompatibilityFrom_5_0(self):
+        """
+        Change XML in order to ensure backward compatibility.
+        """
+
+        XMLThermoPhysicalModelNode = self.case.xmlGetNode('thermophysical_models')
+
         nch = XMLThermoPhysicalModelNode.xmlGetNode('solid_fuels')
         if nch:
             if nch['model'] == 'homogeneous_fuel_moisture_lagr':
@@ -1523,6 +1530,74 @@ class XMLinit(Variables):
                             node.xmlRemoveNode()
         return
 
+    def __backwardCompatibilityFrom_5_1(self):
+        """
+        Change XML in order to ensure backward compatibility.
+        """
+
+    def __backwardCompatibilityFrom_5_2(self):
+        """
+        Change XML in order to ensure backward compatibility.
+        """
+
+        XMLAnaControl = self.case.xmlGetNode('analysis_control')
+        node_steady = XMLAnaControl.xmlGetNode('steady_management')
+        if node_steady:
+            if node_steady['status'] == "on":
+                node_time = XMLAnaControl.xmlGetNode('time_parameters')
+                idtvar = 2
+                n = self.case.xmlGetNode('numerical_parameters')
+                if n:
+                    n = n.xmlGetNode('velocity_pressure_algo', 'choice')
+                    if n:
+                        if n['choice'] == 'simple':
+                            idtvar = -1
+                if idtvar == -1:
+                    iterations = node_steady.xmlGetString('iterations')
+                    if iterations != None:
+                        node_time.xmlSetData('iterations', iterations)
+                    relax_c = node_steady.xmlGetString('relaxation_coefficient')
+                    if relax_c != None:
+                        node_time.xmlSetData('relaxation_coefficient', relax_c)
+                node_time.xmlSetData('time_passing', idtvar)
+            node_steady.xmlRemoveNode()
+
+        XMLThermoPhysicalModelNode = self.case.xmlGetNode('thermophysical_models')
+        npr = XMLThermoPhysicalModelNode.xmlGetNode('radiative_transfer')
+        if npr:
+            node = npr.xmlGetNode('property', name="qrad")
+            if node:
+                node['name'] = "radiative_flux"
+            node = npr.xmlGetNode('property', name="srad")
+            if node:
+                node['name'] = "rad_st"
+            node = npr.xmlGetNode('property', name="flux_convectif")
+            if node:
+                node['name'] = "rad_convective_flux"
+            node = npr.xmlGetNode('property', name="flux_incident")
+            if node:
+                node['name'] = "rad_incident_flux"
+            node = npr.xmlGetNode('property', name="flux_net")
+            if node:
+                node['name'] = "rad_net_flux"
+            node = npr.xmlGetNode('property', name="coeff_ech_conv")
+            if node:
+                node['name'] = "rad_exchange_coefficient"
+            node = npr.xmlGetNode('property', name="absorption")
+            if node:
+                node['name'] = "rad_absorption"
+            node = npr.xmlGetNode('property', name="absorption_coefficient")
+            if node:
+                node['name'] = "rad_absorption_coeff"
+            node = npr.xmlGetNode('property', name="emission")
+            if node:
+                node['name'] = "rad_emission"
+
+    def __backwardCompatibilityCurrentVersion(self):
+        """
+        Change XML in order to ensure backward compatibility.
+        """
+
 #-------------------------------------------------------------------------------
 # XMLinit test case
 #-------------------------------------------------------------------------------
