@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -33,7 +33,7 @@ This module modify the batch file
 from __future__ import print_function
 
 import sys, unittest
-import os, os.path, shutil, sys, string, types, re
+import os, os.path, shutil, sys, types, re
 
 import cs_batch
 
@@ -72,6 +72,8 @@ class BatchRunningModel(Model):
 
         self.dictValues['run_nprocs'] = None
         self.dictValues['run_nthreads'] = None
+        self.dictValues['run_id'] = None
+        self.dictValues['run_build'] = None
 
         # Is a batch file present ?
 
@@ -86,6 +88,8 @@ class BatchRunningModel(Model):
 
         self.dictValues['run_nprocs'] = self.case['runcase'].get_nprocs()
         self.dictValues['run_nthreads'] = self.case['runcase'].get_nthreads()
+        self.dictValues['run_id'] = self.case['runcase'].get_run_id()[0]
+        self.dictValues['run_build'] = self.case['runcase'].get_compute_build()
 
 
     def updateBatchRunOptions(self, keyword=None):
@@ -97,6 +101,10 @@ class BatchRunningModel(Model):
             self.case['runcase'].set_nprocs(self.dictValues['run_nprocs'])
         if (keyword == 'run_nthreads' or not keyword) and self.case['runcase']:
             self.case['runcase'].set_nthreads(self.dictValues['run_nthreads'])
+        if (keyword == 'run_id' or not keyword) and self.case['runcase']:
+            self.case['runcase'].set_run_id(run_id = self.dictValues['run_id'])
+        if (keyword == 'run_build' or not keyword) and self.case['runcase']:
+            self.case['runcase'].set_compute_build(self.dictValues['run_build'])
 
 
     def parseBatchFile(self):
@@ -156,7 +164,6 @@ class BatchRunningModelTestCase(unittest.TestCase):
         self.case = Case(None)
         XMLinit(self.case).initialize()
 
-        self.case['batch_type'] = None
         self.case['scripts_path'] = os.getcwd()
         self.case['runcase'] = cs_runcase.runcase('runcase')
 
@@ -195,7 +202,7 @@ class BatchRunningModelTestCase(unittest.TestCase):
 
     def checkReadBatchPBS(self):
         """ Check whether the BatchRunningModel class could be read file"""
-        self.case['batch_type'] = 'PBS'
+        # TODO update: self.case['batch_type'] = 'PBS'
         mdl = BatchRunningModel(self.case)
 
         dico_PBS = {\
