@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -31,7 +31,7 @@ This module contains the following classes:
 # Standard modules
 #-------------------------------------------------------------------------------
 
-import string, logging
+import logging
 
 #-------------------------------------------------------------------------------
 # Third-party modules
@@ -54,6 +54,7 @@ from code_saturne.Pages.ElectricalModel import ElectricalModel
 from code_saturne.Pages.LocalizationModel import LocalizationModel, Zone
 from code_saturne.Pages.QMeiEditorView import QMeiEditorView
 from code_saturne.Pages.Boundary import Boundary
+from code_saturne.Pages.NotebookModel import NotebookModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -89,6 +90,7 @@ class BoundaryConditionsElectricalView(QWidget, Ui_BoundaryConditionsElectricalF
         self.__boundary = None
         self.__model = ElectricalModel(self.__case)
         self.species_list = []
+        self.notebook = NotebookModel(self.__case)
 
         self.lineEditValuePotElec.textChanged[str].connect(self.slotPotElec)
         self.lineEditValuePotElecIm.textChanged[str].connect(self.slotPotElecIm)
@@ -161,11 +163,9 @@ class BoundaryConditionsElectricalView(QWidget, Ui_BoundaryConditionsElectricalF
         self.modelPotVector.addItem(self.tr("Implicit flux"), 'neumann_implicit')
         self.modelPotVector.disableItem(0)
 
-        self.potVect = 'vec_potential_01'
-        self.modelPotVectLabel = ComboModel(self.comboBoxPotVector, 3, 1)
-        self.modelPotVectLabel.addItem(self.tr('vec_potential_01'), 'vec_potential_01')
-        self.modelPotVectLabel.addItem(self.tr('vec_potential_02'), 'vec_potential_02')
-        self.modelPotVectLabel.addItem(self.tr('vec_potential_03'), 'vec_potential_03')
+        self.potVect = 'vec_potential'
+        self.modelPotVectLabel = ComboModel(self.comboBoxPotVector, 1, 1)
+        self.modelPotVectLabel.addItem(self.tr('vec_potential'), 'vec_potential')
         self.modelPotVectLabel.setItem(str_model = self.potVect)
 
         if self.__model.getElectricalModel() == 'joule':
@@ -334,8 +334,13 @@ class BoundaryConditionsElectricalView(QWidget, Ui_BoundaryConditionsElectricalF
         exa = """#example: """
 
         if not exp:
-            exp = self.potVect + " = 0;"
-        req = [(self.potVect, 'vector potential')]
+            exp = self.potVect + "[0] = 0;\n" + \
+                  self.potVect + "[1] = 0;\n" + \
+                  self.potVect + "[2] = 0;\n"
+
+        req = [(self.potVect + "[0]", 'vector potential X'),
+               (self.potVect + "[1]", 'vector potential Y'),
+               (self.potVect + "[2]", 'vector potential Z')]
 
         sym = [('x', "X cell's gravity center"),
                ('y', "Y cell's gravity center"),
@@ -344,6 +349,9 @@ class BoundaryConditionsElectricalView(QWidget, Ui_BoundaryConditionsElectricalF
                ('t', 'current time'),
                ('iter', 'number of iteration')]
 
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,expression = exp,
                                  required   = req,
                                  symbols    = sym,
@@ -388,4 +396,3 @@ class BoundaryConditionsElectricalView(QWidget, Ui_BoundaryConditionsElectricalF
 #-------------------------------------------------------------------------------
 # End
 #-------------------------------------------------------------------------------
-
