@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -31,7 +31,7 @@ This module contains the following classes:
 # Standard modules
 #-------------------------------------------------------------------------------
 
-import string, logging
+import logging
 
 #-------------------------------------------------------------------------------
 # Third-party modules
@@ -54,6 +54,7 @@ from code_saturne.Pages.LocalizationModel import LocalizationModel, Zone
 from code_saturne.Pages.Boundary import Boundary
 
 from code_saturne.Pages.QMeiEditorView import QMeiEditorView
+from code_saturne.Pages.NotebookModel import NotebookModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -91,6 +92,7 @@ class BoundaryConditionsMobileMeshView(QWidget, Ui_BoundaryConditionsMobileMeshF
         self.__case.undoStopGlobal()
 
         self.__model = MobileMeshModel(self.__case)
+        self.notebook = NotebookModel(self.__case)
 
         self.__comboModel = ComboModel(self.comboMobilBoundary, 6, 1)
         self.__comboModel.addItem(self.tr("Fixed boundary"), "fixed_boundary")
@@ -133,6 +135,9 @@ class BoundaryConditionsMobileMeshView(QWidget, Ui_BoundaryConditionsMobileMeshF
                  ('t', 'current time'),
                  ('iter', 'number of iteration')]
 
+        for (nme, val) in self.notebook.getNotebookList():
+            symbs.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.__case['package'].get_check_syntax(),
                                 expression = exp,
@@ -153,16 +158,25 @@ class BoundaryConditionsMobileMeshView(QWidget, Ui_BoundaryConditionsMobileMeshF
         Called when the combobox changed.
         """
         modelData = self.__comboModel.dicoV2M[str(text)]
-        # Enable/disable formula button.
-        isFormulaEnabled = modelData in ["fixed_velocity", "fixed_displacement"]
-        self.pushButtonMobilBoundary.setEnabled(isFormulaEnabled)
+
+        if modelData == self.__boundary.getALEChoice():
+            return
+
+        self.__boundary.setALEChoice(modelData)
         exp = self.__boundary.getFormula()
+
+        # Hide/Show formula button.
+        # Formula is always reset when changing values, so set
+        # color to red.
+        if modelData in ["fixed_velocity", "fixed_displacement"]:
+            self.pushButtonMobilBoundary.show()
+        else:
+            self.pushButtonMobilBoundary.hide()
         if exp:
-            self.pushButtonMobilBoundary.setStyleSheet("background-color: green")
+            self.pushButtonMobilBoundary.setStyleSheet("background-color: red")
             self.pushButtonMobilBoundary.setToolTip(exp)
         else:
             self.pushButtonMobilBoundary.setStyleSheet("background-color: red")
-        self.__boundary.setALEChoice(modelData)
 
 
     def showWidget(self, b):
@@ -173,8 +187,10 @@ class BoundaryConditionsMobileMeshView(QWidget, Ui_BoundaryConditionsMobileMeshF
             self.__boundary = Boundary("mobile_boundary", b.getLabel(), self.__case)
             modelData = self.__boundary.getALEChoice()
             self.__comboModel.setItem(str_model=modelData)
-            isFormulaEnabled = modelData in ["fixed_velocity", "fixed_displacement"]
-            self.pushButtonMobilBoundary.setEnabled(isFormulaEnabled)
+            if modelData in ["fixed_velocity", "fixed_displacement"]:
+                self.pushButtonMobilBoundary.show()
+            else:
+                self.pushButtonMobilBoundary.hide()
             self.show()
         else:
             self.hideWidget()
