@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -56,6 +56,7 @@ from code_saturne.Pages.QMeiEditorView                import QMeiEditorView
 from code_saturne.Pages.Boundary                      import Boundary
 from code_saturne.Pages.CompressibleModel             import CompressibleModel
 from code_saturne.Pages.AtmosphericFlowsModel         import AtmosphericFlowsModel
+from code_saturne.Pages.NotebookModel                 import NotebookModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -90,6 +91,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         self.__boundary = None
 
         self.__case.undoStopGlobal()
+        self.notebook = NotebookModel(self.__case)
 
         self.lineEditValueThermal.textChanged[str].connect(self.slotValueThermal)
         self.lineEditValueSpecies.textChanged[str].connect(self.slotValueSpecies)
@@ -146,21 +148,21 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         self.modelTypeSpecies.addItem(self.tr("Prescribed value"), 'dirichlet')
         self.modelTypeMeteo.addItem(  self.tr("Prescribed value"), 'dirichlet')
 
-        self.modelTypeThermal.addItem(self.tr("Prescribed value  (user law)"), 'dirichlet_formula')
+        self.modelTypeThermal.addItem(self.tr("Prescribed value (user law)"), 'dirichlet_formula')
         self.modelTypeSpecies.addItem(self.tr("Prescribed value (user law)"), 'dirichlet_formula')
         self.modelTypeMeteo.addItem(  self.tr("Prescribed value (user law)"), 'dirichlet_formula')
 
         if self.nature == 'outlet':
-            self.modelTypeThermal.addItem(self.tr("Prescribed flux"), 'neumann')
-            self.modelTypeSpecies.addItem(self.tr("Prescribed flux"), 'neumann')
-            self.modelTypeMeteo.addItem(  self.tr("Prescribed flux"), 'neumann')
+            self.modelTypeThermal.addItem(self.tr("Prescribed (outgoing) flux"), 'neumann')
+            self.modelTypeSpecies.addItem(self.tr("Prescribed (outgoing) flux"), 'neumann')
+            self.modelTypeMeteo.addItem(  self.tr("Prescribed (outgoing) flux"), 'neumann')
         elif self.nature == 'wall':
-            self.modelTypeThermal.addItem(self.tr("Prescribed flux"), 'neumann')
-            self.modelTypeSpecies.addItem(self.tr("Prescribed flux"), 'neumann')
-            self.modelTypeMeteo.addItem(  self.tr("Prescribed flux"), 'neumann')
-            self.modelTypeThermal.addItem(self.tr("Prescribed flux (user law)"), 'neumann_formula')
-            self.modelTypeSpecies.addItem(self.tr("Prescribed flux (user law)"), 'neumann_formula')
-            self.modelTypeMeteo.addItem(  self.tr("Prescribed flux (user law)"), 'neumann_formula')
+            self.modelTypeThermal.addItem(self.tr("Prescribed (outgoing) flux"), 'neumann')
+            self.modelTypeSpecies.addItem(self.tr("Prescribed (outgoing) flux"), 'neumann')
+            self.modelTypeMeteo.addItem(  self.tr("Prescribed (outgoing) flux"), 'neumann')
+            self.modelTypeThermal.addItem(self.tr("Prescribed (outgoing) flux (user law)"), 'neumann_formula')
+            self.modelTypeSpecies.addItem(self.tr("Prescribed (outgoing) flux (user law)"), 'neumann_formula')
+            self.modelTypeMeteo.addItem(  self.tr("Prescribed (outgoing) flux (user law)"), 'neumann_formula')
             self.modelTypeThermal.addItem(self.tr("Exchange coefficient"), 'exchange_coefficient')
             self.modelTypeSpecies.addItem(self.tr("Exchange coefficient"), 'exchange_coefficient')
             self.modelTypeMeteo.addItem(  self.tr("Exchange coefficient"), 'exchange_coefficient')
@@ -168,7 +170,7 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
             self.modelTypeSpecies.addItem(self.tr("Exchange coefficient (user law)"), 'exchange_coefficient_formula')
             self.modelTypeMeteo.addItem(  self.tr("Exchange coefficient (user law)"), 'exchange_coefficient_formula')
         elif self.nature == 'groundwater':
-            self.modelTypeSpecies.addItem(self.tr("Prescribed flux"), 'neumann')
+            self.modelTypeSpecies.addItem(self.tr("Prescribed (outgoing) flux"), 'neumann')
 
         self.species = ""
         self.species_list = self.sca_mo.getUserScalarNameList()
@@ -203,7 +205,13 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         self.groupBoxMeteo.hide()
 
         if (self.atm.getAtmosphericFlowsModel() != "off" and self.nature == 'wall'):
-            self.groupBoxThermal.hide()
+            self.modelMeteo = ComboModel(self.comboBoxMeteo, 1, 1)
+            if len(self.meteo_list) > 0:
+                self.groupBoxMeteo.show()
+                for m in self.meteo_list:
+                    self.modelMeteo.addItem(self.tr(m), m)
+                self.meteo = self.meteo_list[0]
+                self.modelMeteo.setItem(str_model = self.meteo)
 
         if (self.atm.getAtmosphericFlowsModel() != "off" and \
            (self.nature == 'inlet' or self.nature == 'outlet')):
@@ -334,12 +342,15 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
         self.pushButtonMeteo.setEnabled(False)
         self.pushButtonMeteo.setStyleSheet("background-color: None")
 
-        if (self.meteo_list and (self.nature == 'inlet' or self.nature == 'outlet')):
+        if (self.meteo_list):
             label = self.__boundary.getLabel()
-            nature = "meteo_" + self.nature
+            if self.nature != 'wall':
+                nature = "meteo_" + self.nature
+            else:
+                nature = self.nature
             bb = Boundary(nature, label, self.__case)
 
-            if bb.getMeteoDataStatus() == 'off':
+            if self.nature == 'wall' or bb.getMeteoDataStatus() == 'off':
                 self.meteo_type = self.__boundary.getScalarChoice(self.meteo)
                 self.modelTypeMeteo.setItem(str_model = self.meteo_type)
                 self.labelValueMeteo.setText('Value')
@@ -473,6 +484,9 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
                ('t', 'current time'),
                ('iter', 'number of iteration')]
 
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.__case['package'].get_check_syntax(),
                                 expression = exp,
@@ -507,6 +521,9 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
                ('t', 'current time'),
                ('iter', 'number of iteration')]
 
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.__case['package'].get_check_syntax(),
                                 expression = exp,
@@ -542,6 +559,9 @@ class BoundaryConditionsScalarsView(QWidget, Ui_BoundaryConditionsScalarsForm):
                ('t', 'current time'),
                ('iter', 'number of iteration')]
 
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.__case['package'].get_check_syntax(),
                                 expression = exp,
