@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -32,7 +32,7 @@ This module contains the following classes:
 # Standard modules
 #-------------------------------------------------------------------------------
 
-import string, logging
+import logging
 
 #-------------------------------------------------------------------------------
 # Third-party modules
@@ -144,11 +144,11 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
 
         if MobileMeshModel(self.__case).getMethod() == "off":
             if GroundwaterModel(self.__case).getGroundwaterModel() == "off":
-                lst = ('wall', 'inlet', 'outlet', 'free_inlet_outlet')
+                lst = ('wall', 'inlet', 'outlet', 'free_inlet_outlet', 'imposed_p_outlet')
             else:
-                lst = ('wall', 'inlet', 'outlet', 'free_inlet_outlet', 'groundwater')
+                lst = ('groundwater')
         else:
-            lst = ('wall', 'inlet', 'outlet', 'symmetry', 'free_inlet_outlet')
+            lst = ('wall', 'inlet', 'outlet', 'symmetry', 'free_inlet_outlet', 'imposed_p_outlet')
 
         d = LocalizationModel('BoundaryZone', self.__case)
         for zone in d.getZones():
@@ -164,16 +164,21 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         # Set the case for custom widgets
         self.roughWidget.setup(self.__case)
         self.slidingWidget.setup(self.__case)
+        self.convectiveInletWidget.setup(self.__case)
+        self.mappedInletWidget.setup(self.__case)
         self.velocityWidget.setup(self.__case)
         self.turbulenceWidget.setup(self.__case)
         self.compressibleOutletWidget.setup(self.__case)
         self.coalWidget.setup(self.__case)
         self.scalarsWidget.setup(self.__case)
-        self.meteoWidget.setup(self.__case, self.velocityWidget, self.turbulenceWidget, self.scalarsWidget)
+        self.meteoWidget.setup(self.__case, self.velocityWidget,
+                               self.turbulenceWidget,
+                               self.scalarsWidget)
         self.mobileMeshWidget.setup(self.__case)
         self.radiativeWidget.setup(self.__case)
         self.electricalWidget.setup(self.__case)
         self.hydraulicheadWidget.setup(self.__case)
+        self.pressureWidget.setup(self.__case)
         self.externalHeadLossesWidget.setup(self.__case)
 
         self.__hideAllWidgets()
@@ -202,6 +207,8 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
             self.__selectSymmetryBoundary(boundary)
         elif nature == 'free_inlet_outlet':
             self.__selectInletOutletBoundary(boundary)
+        elif nature == 'imposed_p_outlet':
+            self.__selectImposedPressureOutletBoundary(boundary)
         elif nature == 'groundwater':
             self.__selectGroundwaterBoundary(boundary)
 
@@ -228,6 +235,9 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.mobileMeshWidget.showWidget(boundary)
         self.electricalWidget.showWidget(boundary)
         self.externalHeadLossesWidget.hideWidget()
+        self.pressureWidget.hideWidget()
+        self.convectiveInletWidget.showWidget(boundary)
+        self.mappedInletWidget.showWidget(boundary)
 
 
     def __selectWallBoundary(self, boundary):
@@ -242,6 +252,9 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.electricalWidget.showWidget(boundary)
         self.externalHeadLossesWidget.hideWidget()
         self.hydraulicheadWidget.hideWidget()
+        self.pressureWidget.hideWidget()
+        self.convectiveInletWidget.hideWidget()
+        self.mappedInletWidget.hideWidget()
 
 
     def __selectOutletBoundary(self, boundary):
@@ -261,6 +274,9 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
             self.hydraulicheadWidget.hideWidget()
         else:
             self.hydraulicheadWidget.showWidget(boundary)
+        self.pressureWidget.hideWidget()
+        self.convectiveInletWidget.hideWidget()
+        self.mappedInletWidget.hideWidget()
 
 
     def __selectInletOutletBoundary(self, boundary):
@@ -276,6 +292,27 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.electricalWidget.hideWidget()
         self.externalHeadLossesWidget.showWidget(boundary)
         self.hydraulicheadWidget.hideWidget()
+        self.pressureWidget.hideWidget()
+        self.convectiveInletWidget.hideWidget()
+        self.mappedInletWidget.hideWidget()
+
+
+    def __selectImposedPressureOutletBoundary(self, boundary):
+        """
+        Shows widgets for imposed pressure outlet.
+        """
+        self.coalWidget.hideWidget()
+        self.velocityWidget.hideWidget()
+        self.turbulenceWidget.hideWidget()
+        self.meteoWidget.hideWidget()
+        self.scalarsWidget.hideWidget()
+        self.mobileMeshWidget.hideWidget()
+        self.electricalWidget.hideWidget()
+        self.externalHeadLossesWidget.hideWidget()
+        self.hydraulicheadWidget.hideWidget()
+        self.pressureWidget.showWidget(boundary)
+        self.convectiveInletWidget.hideWidget()
+        self.mappedInletWidget.hideWidget()
 
 
     def __selectGroundwaterBoundary(self, boundary):
@@ -291,6 +328,9 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.electricalWidget.hideWidget()
         self.externalHeadLossesWidget.hideWidget()
         self.hydraulicheadWidget.showWidget(boundary)
+        self.pressureWidget.hideWidget()
+        self.convectiveInletWidget.hideWidget()
+        self.mappedInletWidget.hideWidget()
 
 
     def __selectSymmetryBoundary(self, boundary):
@@ -317,6 +357,9 @@ class BoundaryConditionsView(QWidget, Ui_BoundaryConditionsForm):
         self.electricalWidget.hideWidget()
         self.externalHeadLossesWidget.hideWidget()
         self.hydraulicheadWidget.hideWidget()
+        self.pressureWidget.hideWidget()
+        self.convectiveInletWidget.hideWidget()
+        self.mappedInletWidget.hideWidget()
 
 
     def tr(self, text):
