@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -155,7 +155,7 @@ class StandardItemModelScalars(QStandardItemModel):
         cond = self.bdModel.getRadiativeChoice()
 
         if cond == 'itpimp':
-            lst = [(0, self.tr("Emissivite"), '',  'EPSP',  'emissivity'),
+            lst = [(0, self.tr("Emissivity"), '',  'EPSP',  'emissivity'),
                    (1, self.tr("Initial temperature"), 'K', 'TINTP', 'internal_temperature_profile')]
         if cond == 'ipgrno':
             lst = [(0, self.tr("Emissivity"), '',  'EPSP',  'emissivity'),
@@ -207,14 +207,8 @@ class BoundaryConditionsWallRadiativeTransferView(QWidget,
         self.modelRadiative.addItem(self.tr("Gray or black wall\n"\
                                             " and flux of fixed conduction"), 'ifgrno')
 
-        # Validator
-        validatorZone = IntValidator(self.lineEditZone, min=0)
-        validatorZone.setExclusiveMin(True)
-        self.lineEditZone.setValidator(validatorZone)
-
         # Connections
         self.comboBoxRadiative.activated[str].connect(self.slotRadiativeChoice)
-        self.lineEditZone.textChanged[str].connect(self.slotZone)
 
         self.__case.undoStartGlobal()
 
@@ -234,9 +228,6 @@ class BoundaryConditionsWallRadiativeTransferView(QWidget,
             self.modelScalars = StandardItemModelScalars(self.__boundary)
             self.tableViewScalars.setModel(self.modelScalars)
 
-            self.nb_zone = self.__boundary.getOutputRadiativeZone()
-            self.lineEditZone.setText(str(self.nb_zone))
-
             self.show()
         else:
             self.hideWidget()
@@ -249,14 +240,6 @@ class BoundaryConditionsWallRadiativeTransferView(QWidget,
         self.hide()
 
 
-    @pyqtSlot(str)
-    def slotZone(self, text):
-        if self.lineEditZone.validator().state == QValidator.Acceptable:
-            nb_zone = from_qvariant(text, int)
-            self.__boundary.setOutputRadiativeZone(nb_zone)
-            return nb_zone
-
-
     @pyqtSlot(str)
     def slotRadiativeChoice(self, text):
         cond = self.modelRadiative.dicoV2M[str(text)]
