@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -135,6 +135,7 @@ from code_saturne.Pages.CompressibleModel import CompressibleModel
 from code_saturne.Pages.CoalCombustionModel import CoalCombustionModel
 from code_saturne.Pages.GasCombustionModel import GasCombustionModel
 from code_saturne.Pages.QMeiEditorView import QMeiEditorView
+from code_saturne.Pages.NotebookModel import NotebookModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -166,8 +167,8 @@ rho1 = 1.25051;
 rho2 = 1.7832;
 A = (Y1 / rho1) + (Y2 /rho2);
 density = 1.0 / A;
-
 """
+
     density_h = """# Density
 density = enthalpy / 1040. * 1.29;
 
@@ -180,9 +181,11 @@ rho1 = 1.25051;
 rho2 = 1.7832;
 A = (Y1 / rho1) + (Y2 /rho2);
 density = 1.0 / A;
-
 """
 
+    density_wo = """density = 1.25051;
+
+"""
     molecular_viscosity="""# Sutherland's Formula
 # Gas             Cst    T0      mu0
 # air             120    291.15  18.27e-6
@@ -204,10 +207,9 @@ molecular_viscosity = mu_ref * ((T0+CST) / (temperature+CST)) * (temperature/T0)
 } else {
 molecular_viscosity = -999.0;
 }
-
 """
-    molecular_viscosity_h="""
-CST = 120;
+
+    molecular_viscosity_h="""CST = 120;
 T0 = 291.15;
 mu_ref = 18.27e-6;
 temperature = enthalpy / 1040.;
@@ -217,8 +219,14 @@ molecular_viscosity = mu_ref * (T0+CST / temperature+CST) * (temperature/T0)^(3.
 } else {
 molecular_viscosity = -999.0;
 }
-
 """
+
+    molecular_viscosity_wo="""CST = 120;
+T0 = 291.15;
+mu_ref = 18.27e-6;
+molecular_viscosity = mu_ref * (T0+CST);
+"""
+
     specific_heat="""# specific heat for mixtures of gases
 #
 # Y1 -> mass fraction of component 1
@@ -228,8 +236,10 @@ Cp1 = 520.3;
 Cp2 = 1040.0;
 specific_heat = Y1 * Cp1 + Y2 *Cp2;
 """
+
     volume_viscosity="""# volume_viscosity
 """
+
     thermal_conductivity="""# oxygen
 thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
 
@@ -238,10 +248,9 @@ thermal_conductivity = 6.784141e-5 * temperature + 5.564317e-3;
 
 # hydrogen
 thermal_conductivity = 4.431e-4 * temperature + 5.334e-2;
-
 """
-    thermal_conductivity_h="""
-temperature = enthalpy / 1040.;
+
+    thermal_conductivity_h="""temperature = enthalpy / 1040.;
 thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
 """
 
@@ -259,6 +268,7 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         self.case.undoStopGlobal()
 
         self.mdl = FluidCharacteristicsModel(self.case)
+        self.notebook = NotebookModel(self.case)
 
         if EOS == 1:
             self.ava = eosAva.EosAvailable()
@@ -946,7 +956,9 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         self.m_th = ThermalScalarModel(self.case)
         s = self.m_th.getThermalScalarName()
         mdl = self.m_th.getThermalScalarModel()
-        if mdl == "temperature_celsius":
+        if mdl == "off":
+            exa = FluidCharacteristicsView.density_wo
+        elif mdl == "temperature_celsius":
             TempInContext = "("+s+" + 273.15)"
             exa = FluidCharacteristicsView.density.replace("temperature", TempInContext)
         elif mdl == "enthalpy":
@@ -962,6 +974,9 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         symbols_rho.append(('rho0', 'Density (reference value) = ' + str(rho0_value)))
         symbols_rho.append(('p0', 'Reference pressure = ' + str(ref_pressure)))
 
+        for (nme, val) in self.notebook.getNotebookList():
+            symbols_rho.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
@@ -986,7 +1001,9 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         self.m_th = ThermalScalarModel(self.case)
         s = self.m_th.getThermalScalarName()
         mdl = self.m_th.getThermalScalarModel()
-        if mdl == "temperature_celsius":
+        if mdl == "off":
+            exa = FluidCharacteristicsView.molecular_viscosity_wo
+        elif mdl == "temperature_celsius":
             TempInContext = "("+s+" + 273.15)"
             exa = FluidCharacteristicsView.molecular_viscosity.replace("temperature", TempInContext)
         elif mdl == "enthalpy":
@@ -1009,6 +1026,9 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
             ref_temperature = ReferenceValuesModel(self.case).getTemperature()
             symbols_mu.append(('t0', 'Reference temperature = '+str(ref_temperature)+' K'))
 
+        for (nme, val) in self.notebook.getNotebookList():
+            symbols_mu.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
@@ -1040,6 +1060,9 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         symbols_cp.append(('cp0', 'Specific heat (reference value) = ' + str(cp0_value)))
         symbols_cp.append(('p0', 'Reference pressure = ' + str(ref_pressure)))
 
+        for (nme, val) in self.notebook.getNotebookList():
+            symbols_cp.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
@@ -1072,6 +1095,10 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         symbols_viscv0.append(('p0', 'Reference pressure = '+str(ref_pressure)+' Pa'))
         symbols_viscv0.append(('t0', 'Reference temperature = '+str(ref_temperature)+' K'))
         symbols_viscv0.append(('T', 'Temperature'))
+
+        for (nme, val) in self.notebook.getNotebookList():
+            symbols_viscv0.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
@@ -1112,6 +1139,9 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         symbols_al.append(('lambda0', 'Thermal conductivity (reference value) = ' + str(lambda0_value)))
         symbols_al.append(('p0', 'Reference pressure = ' + str(ref_pressure)))
 
+        for (nme, val) in self.notebook.getNotebookList():
+            symbols_al.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
@@ -1141,6 +1171,10 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         sym.append((str(self.scalar),str(self.scalar)))
         diff0_value = self.m_sca.getScalarDiffusivityInitialValue(self.scalar)
         sym.append((str(name)+'_ref', str(self.scalar)+' diffusion coefficient (reference value) = '+str(diff0_value)+' m^2/s'))
+
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
