@@ -56,6 +56,7 @@ from code_saturne.Pages.QMeiEditorView import QMeiEditorView
 from code_saturne.Pages.GroundwaterLawModel import GroundwaterLawModel
 from code_saturne.Pages.GroundwaterModel import GroundwaterModel
 from code_saturne.Pages.DefineUserScalarsModel import DefineUserScalarsModel
+from code_saturne.Pages.NotebookModel import NotebookModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -133,6 +134,7 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
         self.case.undoStopGlobal()
 
         self.mdl = GroundwaterLawModel(self.case)
+        self.notebook = NotebookModel(self.case)
 
         self.list_scalars = []
         self.m_sca = DefineUserScalarsModel(self.case)
@@ -141,7 +143,7 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
 
         # Create the Page layout.
 
-        # Model and QTreeView for Head Losses
+        # Model and QTreeView
         self.modelGroundwaterLaw = StandardItemModelGroundwaterLaw()
         self.treeView.setModel(self.modelGroundwaterLaw)
 
@@ -152,10 +154,6 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
 
         self.modelNameDiff = ComboModel(self.comboBoxNameDiff,1,1)
 
-        self.modelDiff = ComboModel(self.comboBoxDiff, 2, 1)
-        self.modelDiff.addItem(self.tr('constant'), 'constant')
-        self.modelDiff.addItem(self.tr('variable'), 'variable')
-
         # Set up validators
 
         self.lineEditKs.setValidator(DoubleValidator(self.lineEditKs))
@@ -181,6 +179,11 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
         self.lineEditKsSaturatedYZ.setValidator(DoubleValidator(self.lineEditKsSaturatedYZ))
         self.lineEditThetasSaturated.setValidator(DoubleValidator(self.lineEditThetasSaturated))
         self.lineEditDispersion.setValidator(DoubleValidator(self.lineEditDispersion))
+        self.lineEditSoilDensity.setValidator(DoubleValidator(self.lineEditSoilDensity))
+        self.lineEditDiffusivity.setValidator(DoubleValidator(self.lineEditDiffusivity))
+        self.lineEditKd.setValidator(DoubleValidator(self.lineEditKd))
+        self.lineEditkplus.setValidator(DoubleValidator(self.lineEditkplus))
+        self.lineEditkminus.setValidator(DoubleValidator(self.lineEditkminus))
 
         self.scalar = ""
         scalar_list = self.m_sca.getUserScalarNameList()
@@ -218,10 +221,13 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
         self.lineEditKsSaturatedYZ.textChanged[str].connect(self.slotKsYZSat)
         self.lineEditThetasSaturated.textChanged[str].connect(self.slotThetasSat)
         self.lineEditDispersion.textChanged[str].connect(self.slotDispersion)
+        self.lineEditSoilDensity.textChanged[str].connect(self.slotSoilDensity)
         self.pushButtonUserLaw.clicked.connect(self.slotFormula)
         self.comboBoxNameDiff.activated[str].connect(self.slotNameDiff)
-        self.comboBoxDiff.activated[str].connect(self.slotStateDiff)
-        self.pushButtonDiff.clicked.connect(self.slotFormulaDiff)
+        self.lineEditDiffusivity.textChanged[str].connect(self.slotDiffusivity)
+        self.lineEditKd.textChanged[str].connect(self.slotKd)
+        self.lineEditkplus.textChanged[str].connect(self.slotkplus)
+        self.lineEditkminus.textChanged[str].connect(self.slotkminus)
 
         # Initialize Widgets
 
@@ -252,6 +258,10 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
         self.groupBoxGroundProperties.show()
 
         # ground properties
+        self.groupBoxSoilDensity.show()
+        value = self.mdl.getSoilDensity(name)
+        self.lineEditSoilDensity.setText(str(value))
+
         if GroundwaterModel(self.case).getUnsaturatedZone() == "true":
             self.groupBoxType.show()
 
@@ -307,25 +317,32 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
             self.lineEditThetasSaturated.setText(str(value))
 
         # solute properties
-        if self.scalar == "":
+        scal = self.scalar
+        if scal == "":
             self.groupBoxSoluteProperties.hide()
         else :
             self.groupBoxSoluteProperties.show()
 
-            diff_choice =  self.mdl.getScalarDiffusivityChoice(self.scalar, name)
-            self.modelDiff.setItem(str_model=diff_choice)
-            self.modelNameDiff.setItem(str_model=str(self.scalar))
-            if diff_choice  != 'variable':
-                self.pushButtonDiff.setEnabled(False)
-                self.pushButtonDiff.setStyleSheet("background-color: None")
+            self.modelNameDiff.setItem(str_model=str(scal))
+            value = self.mdl.getGroundWaterScalarPropertyByZone(scal, name, 'diffusivity')
+            self.lineEditDiffusivity.setText(str(value))
+            value = self.mdl.getGroundWaterScalarPropertyByZone(scal, name, 'kd')
+            self.lineEditKd.setText(str(value))
+            # chemistry model
+            if GroundwaterModel(self.case).getChemistryModel(scal) == "EK":
+                self.lineEditkplus.show()
+                self.label_kplus.show()
+                self.lineEditkminus.show()
+                self.label_kminus.show()
+                value = self.mdl.getGroundWaterScalarPropertyByZone(scal, name, 'kplus')
+                self.lineEditkplus.setText(str(value))
+                value = self.mdl.getGroundWaterScalarPropertyByZone(scal, name, 'kminus')
+                self.lineEditkminus.setText(str(value))
             else:
-                self.pushButtonDiff.setEnabled(True)
-                exp = self.mdl.getDiffFormula(self.scalar, name)
-                if exp:
-                    self.pushButtonDiff.setStyleSheet("background-color: green")
-                    self.pushButtonDiff.setToolTip(exp)
-                else:
-                    self.pushButtonDiff.setStyleSheet("background-color: red")
+                self.lineEditkplus.hide()
+                self.label_kplus.hide()
+                self.lineEditkminus.hide()
+                self.label_kminus.hide()
 
         if GroundwaterModel(self.case).getDispersionType() == 'anisotropic':
             self.groupBoxIsotropicDispersion.hide()
@@ -340,10 +357,6 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
             value = self.mdl.getDispersionCoefficient(name, "isotropic")
             self.lineEditDispersion.setText(str(value))
 
-        # force to variable property
-        self.comboBoxDiff.setEnabled(False)
-
-
     def initializeVanGenuchten(self, name):
         """
         initialize variables for groupBoxVanGenuchten
@@ -656,6 +669,14 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
             val = float(text)
             self.mdl.setDispersionCoefficient(name, "isotropic", val)
 
+    @pyqtSlot(str)
+    def slotSoilDensity(self, text):
+        """
+        """
+        label, name, local = self.modelGroundwaterLaw.getItem(self.entriesNumber)
+        if self.lineEditSoilDensity.validator().state == QValidator.Acceptable:
+            val = float(text)
+            self.mdl.setSoilDensity(name, val)
 
     @pyqtSlot()
     def slotFormula(self):
@@ -689,6 +710,9 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
 
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
@@ -702,80 +726,73 @@ class GroundwaterLawView(QWidget, Ui_GroundwaterLawForm):
             self.pushButtonUserLaw.setStyleSheet("background-color: green")
             self.pushButtonUserLaw.setToolTip(result)
 
-
     @pyqtSlot(str)
     def slotNameDiff(self, text):
         """
-        Method to set the variance scalar choosed
+        Method to choose the scalar which properties shall be changed
         """
         label, name, local = self.modelGroundwaterLaw.getItem(self.entriesNumber)
-        choice = self.modelNameDiff.dicoV2M[str(text)]
-        log.debug("slotStateDiff -> %s" % (text))
+        log.debug("slotNameDiff -> %s" % (text))
         self.scalar = str(text)
-
-        self.modelDiff.setItem(str_model=self.mdl.getScalarDiffusivityChoice(self.scalar, name))
-        exp = self.mdl.getDiffFormula(self.scalar, name)
-        if exp:
-            self.pushButtonDiff.setStyleSheet("background-color: green")
-            self.pushButtonDiff.setToolTip(exp)
+        scal = self.scalar
+        value = self.mdl.getGroundWaterScalarPropertyByZone(scal, name, 'diffusivity')
+        self.lineEditDiffusivity.setText(str(value))
+        value = self.mdl.getGroundWaterScalarPropertyByZone(scal, name, 'kd')
+        self.lineEditKd.setText(str(value))
+        if GroundwaterModel(self.case).getChemistryModel(scal) == "EK":
+            self.lineEditkplus.show()
+            self.label_kplus.show()
+            self.lineEditkminus.show()
+            self.label_kminus.show()
+            value = self.mdl.getGroundWaterScalarPropertyByZone(scal, name, 'kplus')
+            self.lineEditkplus.setText(str(value))
+            value = self.mdl.getGroundWaterScalarPropertyByZone(scal, name, 'kminus')
+            self.lineEditkminus.setText(str(value))
         else:
-            self.pushButtonDiff.setStyleSheet("background-color: red")
-
+            self.lineEditkplus.hide()
+            self.label_kplus.hide()
+            self.lineEditkminus.hide()
+            self.label_kminus.hide()
 
     @pyqtSlot(str)
-    def slotStateDiff(self, text):
+    def slotDiffusivity(self, text):
         """
-        Method to set diffusion choice for the coefficient
         """
         label, name, local = self.modelGroundwaterLaw.getItem(self.entriesNumber)
-        choice = self.modelDiff.dicoV2M[str(text)]
-        log.debug("slotStateDiff -> %s" % (text))
+        if self.lineEditDiffusivity.validator().state == QValidator.Acceptable:
+            val = float(text)
+            scal = self.scalar
+            self.mdl.setGroundWaterScalarPropertyByZone(scal, name, 'diffusivity', val)
 
-        if choice != 'variable':
-            self.pushButtonDiff.setEnabled(False)
-            self.pushButtonDiff.setStyleSheet("background-color: None")
-        else:
-            self.pushButtonDiff.setEnabled(True)
-            exp = self.mdl.getDiffFormula(self.scalar, name)
-            if exp:
-                self.pushButtonDiff.setStyleSheet("background-color: green")
-                self.pushButtonDiff.setToolTip(exp)
-            else:
-                self.pushButtonDiff.setStyleSheet("background-color: red")
-
-        self.mdl.setScalarDiffusivityChoice(self.scalar, name, choice)
-
-
-    @pyqtSlot()
-    def slotFormulaDiff(self):
+    @pyqtSlot(str)
+    def slotKd(self, text):
         """
-        User formula for the diffusion coefficient
         """
-        label, namesca, local = self.modelGroundwaterLaw.getItem(self.entriesNumber)
-        name = self.m_sca.getScalarDiffusivityName(self.scalar)
-        exp = self.mdl.getDiffFormula(self.scalar, namesca)
-        delay_name = str(self.scalar) + "_delay"
-        req = [(str(name), str(self.scalar) + ' molecular diffusion (dm)'),
-               (delay_name, str(self.scalar)+ ' delay (R)')]
-        exa = ''
-        sym = [('x', 'cell center coordinate'),
-               ('y', 'cell center coordinate'),
-               ('z', 'cell center coordinate'),
-               ('saturation', 'saturation')]
-        sym.append((str(self.scalar),str(self.scalar)))
-        dialog = QMeiEditorView(self,
-                                check_syntax = self.case['package'].get_check_syntax(),
-                                expression = exp,
-                                required   = req,
-                                symbols    = sym,
-                                examples   = exa)
-        if dialog.exec_():
-            result = dialog.get_result()
-            log.debug("slotFormulaDiff -> %s" % str(result))
-            self.mdl.setDiffFormula(self.scalar, namesca, str(result))
-            self.pushButtonDiff.setStyleSheet("background-color: green")
-            self.pushButtonDiff.setToolTip(result)
+        label, name, local = self.modelGroundwaterLaw.getItem(self.entriesNumber)
+        if self.lineEditKd.validator().state == QValidator.Acceptable:
+            val = float(text)
+            scal = self.scalar
+            self.mdl.setGroundWaterScalarPropertyByZone(scal, name, 'kd', val)
 
+    @pyqtSlot(str)
+    def slotkplus(self, text):
+        """
+        """
+        label, name, local = self.modelGroundwaterLaw.getItem(self.entriesNumber)
+        if self.lineEditkplus.validator().state == QValidator.Acceptable:
+            val = float(text)
+            scal = self.scalar
+            self.mdl.setGroundWaterScalarPropertyByZone(scal, name, 'kplus', val)
+
+    @pyqtSlot(str)
+    def slotkminus(self, text):
+        """
+        """
+        label, name, local = self.modelGroundwaterLaw.getItem(self.entriesNumber)
+        if self.lineEditkminus.validator().state == QValidator.Acceptable:
+            val = float(text)
+            scal = self.scalar
+            self.mdl.setGroundWaterScalarPropertyByZone(scal, name, 'kminus', val)
 
     def tr(self, text):
         """
