@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -129,7 +129,7 @@ class LagrangianOutputView(QWidget, Ui_LagrangianOutputForm):
             self.checkBoxIVISMP.setChecked(False)
 
         if CoalCombustionModel(self.case).getCoalCombustionModel("only") == \
-           "homogeneous_fuel_moisture_lagr":
+           "homogeneous_fuel_moisture":
             status = self.model.getCoalParticleDiameterStatus()
             if status == "on":
                 self.checkBoxIVISDK.setChecked(True)
