@@ -77,13 +77,6 @@ class NumericalParamGlobalModel(Model):
         self.default['hydrostatic_equilibrium'] ='on'
         self.default['wall_pressure_extrapolation'] = 'neumann'
         self.default['time_scheme_order'] = 1
-        self.default['velocity_pressure_algo'] ='simplec'
-        from code_saturne.Pages.CompressibleModel import CompressibleModel
-        if CompressibleModel(self.case).getCompressibleModel() != 'off':
-            self.default['piso_sweep_number'] = 1
-        else:
-            self.default['piso_sweep_number'] = 2
-        del CompressibleModel
         from code_saturne.Pages.GroundwaterModel import GroundwaterModel
         if GroundwaterModel(self.case).getGroundwaterModel() != 'off':
             self.default['gradient_reconstruction'] = 1
@@ -201,32 +194,6 @@ class NumericalParamGlobalModel(Model):
         return choice
 
 
-    @Variables.noUndo
-    def getVelocityPressureAlgorithm(self):
-        """
-        Return velocity pressure algoritm value
-        """
-        node = self.node_np.xmlInitNode('velocity_pressure_algo','choice')
-        value = node['choice']
-        if not value:
-            value = self._defaultValues()['velocity_pressure_algo']
-            self.setVelocityPressureAlgorithm(value)
-        return value
-
-
-    @Variables.noUndo
-    def getPisoSweepNumber(self):
-        """
-        Return piso_sweep_number value
-        """
-        self.node_algo = self.node_np.xmlGetNode('velocity_pressure_algo')
-        value = self.node_algo.xmlGetInt('piso_sweep_number')
-        if not value:
-            value = self._defaultValues()['piso_sweep_number']
-            self.setPisoSweepNumber(value)
-        return value
-
-
     @Variables.undoLocal
     def setTransposedGradient(self, status):
         """
@@ -295,8 +262,8 @@ class NumericalParamGlobalModel(Model):
         """
         Put value of density_relaxation
         """
-        self.isGreater(value, 0.0)
-        self.isLowerOrEqual(value, 1.0)
+        self.isGreaterOrEqual(value, 0.0)
+        self.isLower(value, 1.0)
         self.node_np.xmlSetData('density_relaxation', value)
 
 
@@ -351,31 +318,6 @@ class NumericalParamGlobalModel(Model):
             self.node_np.xmlRemoveChild('time_scheme_order')
 
 
-    @Variables.undoGlobal
-    def setVelocityPressureAlgorithm(self, value):
-        """
-        Put value of velocity pressure algorithm
-        """
-        self.isInList(value, ('simple', 'simplec', 'piso'))
-        node = self.node_np.xmlInitNode('velocity_pressure_algo', 'choice')
-        node['choice'] = value
-        if value == 'simple' or value =='simplec':
-            self.setPisoSweepNumber(1)
-        elif self.getPisoSweepNumber() < self._defaultValues()['piso_sweep_number']:
-            value = self._defaultValues()['piso_sweep_number']
-            self.setPisoSweepNumber(value)
-
-
-    @Variables.undoLocal
-    def setPisoSweepNumber(self, value):
-        """
-        Put value of NTRUP
-        """
-        self.isInt(value)
-        self.node_algo = self.node_np.xmlGetNode('velocity_pressure_algo')
-        self.node_algo.xmlSetData('piso_sweep_number',value)
-
-
 #-------------------------------------------------------------------------------
 # NumericalParamEquat test case
 #-------------------------------------------------------------------------------
@@ -531,39 +473,6 @@ class NumericalParamGlobalTestCase(ModelTest):
         assert model.getTimeSchemeOrder() == 2,\
                 'Could not get time scheme order in NumericalParamGlobalModel'
 
-    def checkGetandSetVelocityPressureAlgorithm(self):
-        """
-        Check whether velocity pressure algorithm could be set and get
-        """
-        model = NumericalParamGlobalModel(self.case)
-        model.setVelocityPressureAlgorithm('piso')
-        doc = '''<numerical_parameters>
-                         <velocity_pressure_algo choice="piso"/>
-                 </numerical_parameters>'''
-        assert model.node_np== self.xmlNodeFromString(doc), \
-                    'Could not set velocity pressure algorithm'
-        assert model.getVelocityPressureAlgorithm() == 'piso',\
-                    'Could not get velocity pressure algorithm'
-
-    def checkGetandSetNterup(self):
-        """
-        Check whether velocity pressure algorithm could be set and get
-        """
-        model = NumericalParamGlobalModel(self.case)
-        model.setVelocityPressureAlgorithm('piso')
-        model.setNterup(3)
-        doc = '''<numerical_parameters>
-                         <velocity_pressure_algo choice="piso">
-                                 <piso_sweep_number>
-                                         3
-                                 </piso_sweep_number>
-                         </velocity_pressure_algo>
-                 </numerical_parameters>'''
-        assert model.node_np == self.xmlNodeFromString(doc), \
-                    'Could not set nterup'
-        assert model.getNterup() == 3,\
-                    'Could not get nterup'
-
 
 def suite():
     testSuite = unittest.makeSuite(NumericalParamGlobalTestCase, "check")
