@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -56,6 +56,7 @@ from code_saturne.Pages.SourceTermsModel import SourceTermsModel
 from code_saturne.Pages.QMeiEditorView import QMeiEditorView
 from code_saturne.Pages.OutputVolumicVariablesModel import OutputVolumicVariablesModel
 from code_saturne.Pages.GroundwaterModel import GroundwaterModel
+from code_saturne.Pages.NotebookModel import NotebookModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -86,6 +87,7 @@ class SourceTermsView(QWidget, Ui_SourceTermsForm):
         self.parent = parent
 
         self.mdl     = SourceTermsModel(self.case)
+        self.notebook = NotebookModel(self.case)
         self.therm   = ThermalScalarModel(self.case)
         self.th_sca  = DefineUserScalarsModel(self.case)
         self.volzone = LocalizationModel('VolumicZone', self.case)
@@ -102,6 +104,7 @@ class SourceTermsView(QWidget, Ui_SourceTermsForm):
 
         # 1/ Combo box models
 
+        # FIXME really useful to duplicate this comboBox for ground water flow?
         self.modelSpecies  = ComboModel(self.comboBoxSpecies, 1, 1)
         self.modelSpecies2 = ComboModel(self.comboBoxSpecies2, 1, 1)
         self.modelZone     = ComboModel(self.comboBoxZone, 1, 1)
@@ -123,6 +126,7 @@ class SourceTermsView(QWidget, Ui_SourceTermsForm):
 
             if GroundwaterModel(self.case).getGroundwaterModel() != "off":
                 self.groupBoxStandard.hide()
+                # FIXME really useful to duplicate this groupBox for ground water flow?
                 self.groupBoxTransport.show()
                 if (zone.getNature()['momentum_source_term'] == "on"):
                     self.groupBoxRichards.show()
@@ -144,6 +148,17 @@ class SourceTermsView(QWidget, Ui_SourceTermsForm):
                     self.zone = name
         self.modelZone.setItem(str_model = self.zone)
 
+        scalar_list = self.th_sca.getUserScalarNameList()
+        for s in self.th_sca.getScalarsVarianceList():
+            if s in scalar_list: scalar_list.remove(s)
+        if scalar_list != []:
+            for scalar in scalar_list:
+                self.scalar = scalar
+                self.modelSpecies.addItem(self.tr(scalar),self.scalar)
+                self.modelSpecies2.addItem(self.tr(scalar),self.scalar)
+            self.modelSpecies.setItem(str_model = self.scalar)
+            self.modelSpecies2.setItem(str_model = self.scalar)
+
         # 2/ Connections
 
         self.comboBoxZone.activated[str].connect(self.slotZone)
@@ -164,7 +179,7 @@ class SourceTermsView(QWidget, Ui_SourceTermsForm):
 
     def initialize(self, zone_num):
         """
-        Initialize widget when a new volumic zone is choosen
+        Initialize widget when a new volumic zone is chosen
         """
         zone = self.case.xmlGetNode("zone", id=zone_num)
 
@@ -179,15 +194,19 @@ class SourceTermsView(QWidget, Ui_SourceTermsForm):
                 self.pushButtonMomentum.setStyleSheet("background-color: red")
 
             if GroundwaterModel(self.case).getGroundwaterModel() != "off":
+                self.groupBoxRichards.show()
                 exp = self.mdl.getRichardsFormula(self.zone)
                 if exp:
                     self.pushButtonRichards.setToolTip(exp)
                     self.pushButtonRichards.setStyleSheet("background-color: green")
                 else:
                     self.pushButtonRichards.setStyleSheet("background-color: red")
+            else:
+                self.groupBoxRichards.hide()
         else:
             self.labelMomentum.hide()
             self.pushButtonMomentum.hide()
+            self.groupBoxRichards.hide()
 
         if zone['thermal_source_term']  == "on":
             self.pushButtonThermal.show()
@@ -207,39 +226,22 @@ class SourceTermsView(QWidget, Ui_SourceTermsForm):
             self.pushButtonSpecies.show()
             self.labelSpecies.show()
 
-            self.scalar = ""
-            scalar_list = self.th_sca.getUserScalarNameList()
-            for s in self.th_sca.getScalarsVarianceList():
-                if s in scalar_list: scalar_list.remove(s)
-            if scalar_list != []:
-                for scalar in scalar_list:
-                    self.scalar = scalar
-                    self.modelSpecies.addItem(self.tr(scalar),self.scalar)
-                self.modelSpecies.setItem(str_model = self.scalar)
-                exp = self.mdl.getSpeciesFormula(self.zone, self.scalar)
-                if exp:
-                    self.pushButtonSpecies.setToolTip(exp)
-                    self.pushButtonSpecies.setStyleSheet("background-color: green")
-                else:
-                    self.pushButtonSpecies.setStyleSheet("background-color: red")
+            exp = self.mdl.getSpeciesFormula(self.zone, self.scalar)
+            if exp:
+                self.pushButtonSpecies.setToolTip(exp)
+                self.pushButtonSpecies.setStyleSheet("background-color: green")
+            else:
+                self.pushButtonSpecies.setStyleSheet("background-color: red")
 
             if GroundwaterModel(self.case).getGroundwaterModel() != "off":
                 self.groupBoxTransport.show()
-                self.scalar = ""
-                scalar_list = self.th_sca.getUserScalarNameList()
-                for s in self.th_sca.getScalarsVarianceList():
-                    if s in scalar_list: scalar_list.remove(s)
-                if scalar_list != []:
-                    for scalar in scalar_list:
-                        self.scalar = scalar
-                        self.modelSpecies2.addItem(self.tr(scalar),self.scalar)
-                    self.modelSpecies2.setItem(str_model = self.scalar)
-                    exp = self.mdl.getGroundWaterSpeciesFormula(self.zone, self.scalar)
-                    if exp:
-                        self.pushButtonSpecies2.setToolTip(exp)
-                        self.pushButtonSpecies2.setStyleSheet("background-color: green")
-                    else:
-                        self.pushButtonSpecies2.setStyleSheet("background-color: red")
+
+                exp = self.mdl.getGroundWaterSpeciesFormula(self.zone, self.scalar)
+                if exp:
+                    self.pushButtonSpecies2.setToolTip(exp)
+                    self.pushButtonSpecies2.setStyleSheet("background-color: green")
+                else:
+                    self.pushButtonSpecies2.setStyleSheet("background-color: red")
             else:
                 self.groupBoxTransport.hide()
         else:
@@ -261,14 +263,15 @@ class SourceTermsView(QWidget, Ui_SourceTermsForm):
     @pyqtSlot(str)
     def slotSpeciesChoice(self, text):
         """
-        INPUT label for choice of zone
+        INPUT label for choice of species
         """
-        self.scalar= self.modelSpecies.dicoV2M[str(text)]
+        self.scalar = self.modelSpecies.dicoV2M[str(text)]
         exp = self.mdl.getSpeciesFormula(self.zone, self.scalar)
         if exp:
             self.pushButtonSpecies.setToolTip(exp)
             self.pushButtonSpecies.setStyleSheet("background-color: green")
         else:
+            self.pushButtonSpecies.setToolTip("Use the formula editor to define a source term for this species.")
             self.pushButtonSpecies.setStyleSheet("background-color: red")
 
 
@@ -283,10 +286,14 @@ class SourceTermsView(QWidget, Ui_SourceTermsForm):
 dSudu = 0;\ndSudv = 0;\ndSudw = 0;\n
 dSvdu = 0;\ndSvdv = 0;\ndSvdw = 0;\n
 dSwdu = 0;\ndSwdv = 0;\ndSwdw = 0;\n"""
-        exa = """#example: """
-        req = [('Su', "x velocity"),
-               ('Sv', "y velocity"),
-               ('Sw', "z velocity"),
+        exa = """#example:\n
+tau = 10.; # relaxation time (s)\n
+vel_x_imp = 1.5; #target velocity (m/s)\n
+Su = rho * (vel_x_imp - velocity[0]) / tau;\n
+dSudu = - rho / tau; # Jacobian of the source term"""
+        req = [('Su', "x component of the momentum source term"),
+               ('Sv', "y component of the momentum source term"),
+               ('Sw', "z component of the momentum source term"),
                ('dSudu', "x component x velocity derivative"),
                ('dSudv', "x component y velocity derivative"),
                ('dSudw', "x component z velocity derivative"),
@@ -300,9 +307,13 @@ dSwdu = 0;\ndSwdv = 0;\ndSwdw = 0;\n"""
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate')]
 
-        sym.append( ("velocity[0]", 'X velocity component'))
-        sym.append( ("velocity[1]", 'Y velocity component'))
-        sym.append( ("velocity[2]", 'Z velocity component'))
+        sym.append( ("velocity[0]", 'x velocity component'))
+        sym.append( ("velocity[1]", 'y velocity component'))
+        sym.append( ("velocity[2]", 'z velocity component'))
+        sym.append( ("rho", 'local density (kg/m^3)'))
+
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
 
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
@@ -335,6 +346,9 @@ dSwdu = 0;\ndSwdv = 0;\ndSwdw = 0;\n"""
         name = self.th_sca.getScalarName(self.scalar)
         sym.append((name, 'current species'))
 
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
@@ -355,10 +369,9 @@ dSwdu = 0;\ndSwdv = 0;\ndSwdw = 0;\n"""
         """
         exp = self.mdl.getGroundWaterSpeciesFormula(self.zone, self.scalar)
         if not exp:
-            exp = """Q = 0;\nlambda = 0;\n"""
+            exp = """Q = 0;"""
         exa = """#example: """
-        req = [('Q', 'species source term'),
-               ('lambda', 'radioactive decay')]
+        req = [('Q', 'species source term')]
         sym = [('x', 'cell center coordinate'),
                ('y', 'cell center coordinate'),
                ('z', 'cell center coordinate'),
@@ -367,6 +380,9 @@ dSwdu = 0;\ndSwdv = 0;\ndSwdw = 0;\n"""
         name = self.th_sca.getScalarName(self.scalar)
         sym.append((name, 'current species'))
 
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
@@ -395,6 +411,9 @@ dSwdu = 0;\ndSwdv = 0;\ndSwdw = 0;\n"""
                ('z', 'cell center coordinate'),
                ('t', 'current time')]
 
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
@@ -452,6 +471,10 @@ dSwdu = 0;\ndSwdv = 0;\ndSwdw = 0;\n"""
             sym.append(('total_energy', 'thermal scalar'))
         else:
             sym.append(('temperature', 'thermal scalar'))
+
+        for (nme, val) in self.notebook.getNotebookList():
+            sym.append((nme, 'value (notebook) = ' + str(val)))
+
         dialog = QMeiEditorView(self,
                                 check_syntax = self.case['package'].get_check_syntax(),
                                 expression = exp,
