@@ -87,6 +87,7 @@ class LabelDelegate(QItemDelegate):
 
 
     def setEditorData(self, editor, index):
+        editor.setAutoFillBackground(True)
         value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         self.old_p_value = str(value)
         editor.setText(value)
@@ -98,7 +99,7 @@ class LabelDelegate(QItemDelegate):
         if editor.validator().state == QValidator.Acceptable:
             p_value = str(editor.text())
 
-            if p_value in self.mdl.getTimeAverageLabels():
+            if p_value in self.mdl.getTimeAverageNames():
                 title = self.tr("Warning")
                 msg   = self.tr("This time moment field is already used.\n"\
                                 "Please choose another one.")
@@ -106,7 +107,7 @@ class LabelDelegate(QItemDelegate):
                 return
 
             if p_value and p_value != self.old_p_value:
-                self.mdl.setLabel(self.old_p_value, p_value)
+                self.mdl.setName(self.old_p_value, p_value)
                 model.setData(index, to_qvariant(p_value), Qt.DisplayRole)
 
 #-------------------------------------------------------------------------------
@@ -173,8 +174,9 @@ class StartValueDelegate(QItemDelegate):
         return editor
 
     def setEditorData(self, editor, index):
+        editor.setAutoFillBackground(True)
         value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
-        editor.setText(value)
+        editor.setText(str(value))
 
     def setModelData(self, editor, model, index):
         if editor.validator().state == QValidator.Acceptable:
@@ -562,6 +564,7 @@ class TimeAveragesView(QWidget, Ui_TimeAveragesForm):
             lst = [str(s) for s in lst]
             if lst[0] == "":
                 lst.remove(lst[0])
+            self.label_select = self.averageInfo()[1]
             self.mdl.setVariable(self.label_select, lst)
 
             self.updateView()
@@ -575,6 +578,7 @@ class TimeAveragesView(QWidget, Ui_TimeAveragesForm):
         self.modelDrop.removeRows(self.listViewDrop.currentIndex().row(), 1)
         liste = self.modelDrop.stringList()
         liste = [str(s) for s in liste]
+        self.label_select = self.averageInfo()[1]
         self.mdl.setVariable(self.label_select, liste)
 
         self.updateView()
