@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -27,7 +27,7 @@ This module contains the following classes and function:
 #-------------------------------------------------------------------------------
 
 import sys, unittest
-import os, sys, string, types
+import os, sys, types
 
 #-------------------------------------------------------------------------------
 # Application modules import
@@ -218,7 +218,8 @@ class TurboMachineryModel(Variables, Model):
         """
         Put model for turbo machinery
         """
-        self.isInList(model, ('off', 'frozen', 'transient'))
+        self.isInList(model, ('off', 'frozen', 'transient',
+                              'frozen_coupled', 'transient_coupled'))
         self.node_turbo.xmlSetAttribute(model = model)
 
         if model == 'off':
