@@ -175,6 +175,7 @@ class LabelDelegate(QItemDelegate):
 
 
     def setEditorData(self, editor, index):
+        editor.setAutoFillBackground(True)
         v = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         self.p_value = str(v)
         editor.setText(v)
@@ -483,7 +484,9 @@ class ManageCasesView(QWidget, Ui_ManageCasesForm):
         path = os.path.abspath(os.path.join(self.mdl.repo, study))
         os.chdir(path)
 
-        dialog = QFileDialog(self, title, path)
+        dialog = QFileDialog()
+        dialog.setWindowTitle(title)
+        dialog.setDirectory(path)
         dialog.setFileMode(QFileDialog.DirectoryOnly)
 
         if dialog.exec_() == 1:
@@ -512,7 +515,9 @@ class ManageCasesView(QWidget, Ui_ManageCasesForm):
         path = os.path.abspath(self.mdl.repo)
         os.chdir(path)
 
-        dialog = QFileDialog(self, title, path)
+        dialog = QFileDialog()
+        dialog.setWindowTitle(title)
+        dialog.setDirectory(path)
         dialog.setFileMode(QFileDialog.DirectoryOnly)
 
         if dialog.exec_() == 1:
