@@ -410,8 +410,6 @@ class Package:
             line = re.sub(re_intsize32, '', line)
             line = re.sub(re_intsize64, '', line)
             line = re.sub(re_idxsize64, '-DIDXSIZE64 -DINTSIZE64', line)
-            if ldflags_add and line[0:7] == 'LDFLAGS':
-                line = line[:-1] + ldflags_add
 
             fd.write(line)
 
@@ -599,12 +597,12 @@ class Setup:
             Package(name="HDF5",
                     description="Hierarchical Data Format",
                     package="hdf5",
-                    version="1.8.20",
-                    archive="hdf5-1.8.20.tar.gz",
-                    url="https://support.hdfgroup.org/ftp/HDF5/releases/hdf5-1.8/hdf5-1.8.20/src/%s")
+                    version="1.10.4",
+                    archive="hdf5-1.10.4.tar.gz",
+                    url="https://support.hdfgroup.org/ftp/HDF5/releases/hdf5-1.10/hdf5-1.10.4/src/%s")
 
         p = self.packages['hdf5']
-        p.config_opts = "--enable-production"
+        p.config_opts = "--enable-build-mode=production"
 
         # CGNS library
 
@@ -625,8 +623,8 @@ class Setup:
             Package(name="MED",
                     description="Model for Exchange of Data",
                     package="med",
-                    version="3.3.1",
-                    archive="med-3.3.1.tar.gz",
+                    version="4.0.0",
+                    archive="med-4.0.0.tar.gz",
                     url="http://files.salome-platform.org/Salome/other/%s")
 
         p = self.packages['med']
